(self.webpackChunk=self.webpackChunk||[]).push([[9954],{7815:function(i){i.exports='<div id="streamingSettingsPage" data-role="page" class="page type-interior playbackConfigurationPage withTabs"> <div> <div class="content-primary"> <form class="streamingSettingsForm"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${TabStreaming}</h2> </div> <div class="inputContainer"> <input is="emby-input" type="number" id="txtRemoteClientBitrateLimit" inputmode="decimal" pattern="[0-9]*(\\.[0-9]+)?" min="0" step=".25" label="${LabelRemoteClientBitrateLimit}"/> <div class="fieldDescription">${LabelRemoteClientBitrateLimitHelp}</div> </div> </div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </form> </div> </div> </div> '}}]);