(self.webpackChunk=self.webpackChunk||[]).push([[7176],{4238:function(e,t,n){"use strict";n.r(t),n.d(t,{default:function(){return a}}),n(63238),n(61418),n(5769);var r=n(53913);function i(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}var a=function(){function e(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.name="Photo Player",this.type="mediaplayer",this.id="photoplayer",this.priority=1}var t,a;return t=e,(a=[{key:"play",value:function(e){return new Promise((function(t,i){Promise.all([n.e(5836),n.e(1483)]).then(n.bind(n,1483)).then((function(n){var i=n.default,a=e.startIndex||0;r.ZP.currentApiClient().getCurrentUser().then((function(n){new i({showTitle:!1,cover:!1,items:e.items,startIndex:a,interval:11e3,interactive:!0,user:n}).show(),t()}))}))}))}},{key:"canPlayMediaType",value:function(e){return"photo"===(e||"").toLowerCase()}}])&&i(t.prototype,a),e}()}}]);