(self.webpackChunk=self.webpackChunk||[]).push([[9850],{85227:function(a){a.exports='<div id="wizardFinishPage" data-role="page" class="page standalonePage wizardPage"> <div class="padded-left padded-right padded-top"> <div class="ui-corner-all ui-shadow wizardContent"> <h1>${LabelYoureDone}</h1> <p style="margin:2em 0">${WizardCompleted}</p> <div class="wizardNavigation"> <button is="emby-button" type="button" class="raised button-cancel" onclick="history.back()"> <span class="material-icons arrow_back"></span> <span>${Previous}</span> </button> <button is="emby-button" type="button" class="raised btnWizardNext button-submit"> <span class="material-icons check"></span> <span>${LabelFinish}</span> </button> </div> </div> </div> </div> '}}]);