(self.webpackChunk=self.webpackChunk||[]).push([[3853],{43542:function(e){e.exports='<div id="devicePage" data-role="page" class="page type-interior devicesPage noSecondaryNavPage"> <div> <div class="content-primary"> <form class="deviceForm"> <div class="verticalSection verticalSection-extrabottompadding"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle reportedName"></h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/server/devices.html">${Help}</a> </div> <div class="inputContainer"> <input is="emby-input" type="text" id="txtCustomName" label="${LabelDisplayName}"/> <div class="fieldDescription">${LabelCustomDeviceDisplayNameHelp}</div> </div> </div> <div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </div> </form> </div> </div> </div> '}}]);