(self.webpackChunk=self.webpackChunk||[]).push([[3792],{64948:function(e){e.exports='<div id="devicesPage" data-role="page" class="page type-interior devicesPage noSecondaryNavPage"> <div> <div class="content-primary"> <div class="verticalSection verticalSection"> <div class="sectionTitleContainer sectionTitleContainer-cards flex align-items-center"> <h2 class="sectionTitle sectionTitle-cards">${HeaderDevices}</h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/server/devices.html">${Help}</a> <button id="deviceDeleteAll" is="emby-button" type="button" class="raised button-alt headerHelpButton">${DeleteAll}</button> </div> </div> <div is="emby-itemscontainer" class="devicesList vertical-wrap" data-multiselect="false"></div> </div> </div> </div> '}}]);