(self.webpackChunk=self.webpackChunk||[]).push([[3827],{70474:function(t,e,n){"use strict";n.r(e),n.d(e,{default:function(){return r}}),n(5769),n(61013),n(63238),n(61418),n(17460),n(14078),n(71848);var i=n(6594),a=(n(78066),n(50447),n(76543));function o(){return function(t){i.ZP.show();var e=ApiClient;e.getJSON(e.getUrl("Startup/Configuration")).then((function(n){n.UICulture=$("#selectLocalizationLanguage",t).val(),e.ajax({type:"POST",data:JSON.stringify(n),url:e.getUrl("Startup/Configuration"),contentType:"application/json"}).then((function(){a.ZP.navigate("wizarduser.html")}))}))}($(this).parents(".page")),!1}function r(t,e){$(".wizardStartForm",t).on("submit",o),t.addEventListener("viewshow",(function(){document.querySelector(".skinHeader").classList.add("noHomeButtonHeader"),i.ZP.show();var t=this,e=ApiClient,n=e.getJSON(e.getUrl("Startup/Configuration")),a=e.getJSON(e.getUrl("Localization/Options"));Promise.all([n,a]).then((function(e){!function(t,e,n){$("#selectLocalizationLanguage",t).html(n.map((function(t){return'<option value="'+t.Value+'">'+t.Name+"</option>"}))).val(e.UICulture),i.ZP.hide()}(t,e[0],e[1])}))})),t.addEventListener("viewhide",(function(){document.querySelector(".skinHeader").classList.remove("noHomeButtonHeader")}))}}}]);