(self.webpackChunk=self.webpackChunk||[]).push([[1591],{89618:function(e){e.exports='<div id="repositories" data-role="page" class="page type-interior withTabs fullWidthContent"> <div> <div class="content-primary"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${TabRepositories}</h2> <button is="emby-button" type="button" class="fab btnNewRepository submit" style="margin-left:1em" title="${Add}"> <span class="material-icons add" aria-hidden="true"></span> </button> </div> <div id="repositories"></div> <div id="none" class="noItemsMessage centerMessage hide"> <h1>${MessageNoRepositories}</h1> <p>${MessageAddRepository}</p> </div> </div> </div> </div> '}}]);