(self.webpackChunk=self.webpackChunk||[]).push([[6791],{80579:function(e,t,n){"use strict";n.r(t),n.d(t,{default:function(){return u}}),n(5769),n(63238),n(61418),n(17460),n(14078);var a=n(6594),r=(n(65219),n(78066),n(50447),n(76543));function o(e){return function(e){a.ZP.show();var t=ApiClient;t.getJSON(t.getUrl("Startup/Configuration")).then((function(n){n.PreferredMetadataLanguage=e.querySelector("#selectLanguage").value,n.MetadataCountryCode=e.querySelector("#selectCountry").value,t.ajax({type:"POST",data:JSON.stringify(n),url:t.getUrl("Startup/Configuration"),contentType:"application/json"}).then((function(){a.ZP.hide(),r.ZP.navigate("wizardremoteaccess.html")}))}))}(this),e.preventDefault(),!1}function u(e,t){e.querySelector(".wizardSettingsForm").addEventListener("submit",o),e.addEventListener("viewshow",(function(){document.querySelector(".skinHeader").classList.add("noHomeButtonHeader"),function(e){a.ZP.show();var t=ApiClient,n=t.getJSON(t.getUrl("Startup/Configuration")),r=t.getCultures(),o=t.getCountries();Promise.all([n,r,o]).then((function(t){!function(e,t,n,r){!function(e,t){var n="";n+="<option value=''></option>";for(var a=0,r=t.length;a<r;a++){var o=t[a];n+="<option value='"+o.TwoLetterISOLanguageName+"'>"+o.DisplayName+"</option>"}e.innerHTML=n}(e.querySelector("#selectLanguage"),n),function(e,t){var n="";n+="<option value=''></option>";for(var a=0,r=t.length;a<r;a++){var o=t[a];n+="<option value='"+o.TwoLetterISORegionName+"'>"+o.DisplayName+"</option>"}e.innerHTML=n}(e.querySelector("#selectCountry"),r),e.querySelector("#selectLanguage").value=t.PreferredMetadataLanguage,e.querySelector("#selectCountry").value=t.MetadataCountryCode,a.ZP.hide()}(e,t[0],t[1],t[2])}))}(this)})),e.addEventListener("viewhide",(function(){document.querySelector(".skinHeader").classList.remove("noHomeButtonHeader")}))}}}]);