(self.webpackChunk=self.webpackChunk||[]).push([[5584],{75584:function(e,a,t){"use strict";t.r(a),t(27471),t(61013);var n=t(47005),o=t(53218);n.Events.on(o.O,"playerchange",(function(e,a,t,n){n&&a&&(n.isLocalPlayer?a.isLocalPlayer?console.debug("Skipping remote control autoplay because newPlayer is a local player"):function(e,a){var t=o.O.getPlayerState(e),n=t.NowPlayingItem;n&&o.O.getPlaylist(e).then((function(l){var i=l.map((function(e){return e.Id})),r=(t.PlayState||{}).PositionTicks||0,s=i.indexOf(n.Id)||0;o.O.stop(e).then((function(){o.O.play({ids:i,serverId:n.ServerId,startPositionTicks:r,startIndex:s},a)}))}))}(n,a):console.debug("Skipping remote control autoplay because oldPlayer is not a local player"))}))}}]);