(self.webpackChunk=self.webpackChunk||[]).push([[6066],{91949:function(s,n,e){"use strict";e.r(n);var i,t,r,o,a,c,d=e(47005),u=e(53218),h=e(83094),l=e(47518);function g(){this.classList.add("hide")}function f(){c&&(clearTimeout(c),c=null)}function b(){f();var s=t;s&&(a?(s.offsetWidth,requestAnimationFrame((function(){s.classList.add("iconOsd-hidden"),h.ZP.addEventListener(s,h.ZP.whichTransitionEvent(),g,{once:!0})}))):g.call(s))}function m(s){var n,e;(n=t)||(a=l.Z.supportsCssAnimation(),(n=document.createElement("div")).classList.add("hide"),n.classList.add("iconOsd"),n.classList.add("iconOsd-hidden"),n.classList.add("brightnessOsd"),n.innerHTML='<span class="material-icons iconOsdIcon brightness_high"></span><div class="iconOsdProgressOuter"><div class="iconOsdProgressInner brightnessOsdProgressInner"></div></div>',r=n.querySelector(".material-icons"),o=n.querySelector(".iconOsdProgressInner"),document.body.appendChild(n),t=n),e=u.O.getBrightness(this),r&&function(s,n){s.classList.remove("brightness_high","brightness_medium","brightness_low"),s.classList.add(n)}(r,e>=80?"brightness_high":e>=20?"brightness_medium":"brightness_low"),o&&(o.style.width=(e||0)+"%"),function(){f();var s=t;h.ZP.removeEventListener(s,h.ZP.whichTransitionEvent(),g,{once:!0}),s.classList.remove("hide"),s.offsetWidth,requestAnimationFrame((function(){s.classList.remove("iconOsd-hidden"),c=setTimeout(b,3e3)}))}()}function p(s){s!==i&&(function(){var s=i;s&&(d.Events.off(s,"brightnesschange",m),d.Events.off(s,"playbackstop",b),i=null)}(),i=s,s&&(b(),d.Events.on(s,"brightnesschange",m),d.Events.on(s,"playbackstop",b)))}e(61866),e(56561),d.Events.on(u.O,"playerchange",(function(){p(u.O.getCurrentPlayer())})),p(u.O.getCurrentPlayer())},50183:function(s,n,e){"use strict";var i=e(93476),t=e.n(i)()((function(s){return s[1]}));t.push([s.id,".iconOsd{position:fixed;top:7%;right:3%;z-index:100000;background:#222;background:rgba(0,0,0,.8);padding:1em;color:#fff;-webkit-backdrop-filter:blur(5px);backdrop-filter:blur(5px);border-radius:.25em;transition:opacity .2s ease-out}.iconOsd-hidden{opacity:0}.iconOsdIcon{font-size:320%;display:block;margin:.25em .7em}.iconOsdProgressOuter{margin:1.5em .25em 1em;height:.35em;background:#222;border-radius:.25em}.iconOsdProgressInner{background:#00a4dc;height:100%;border-radius:.25em}.brightnessOsdProgressInner{background:#ff9800}",""]),n.Z=t},61866:function(s,n,e){"use strict";var i=e(1892),t=e.n(i),r=e(50183);t()(r.Z,{insert:"head",singleton:!1}),r.Z.locals}}]);