(self.webpackChunk=self.webpackChunk||[]).push([[412],{412:function(a){"use strict";a.exports=JSON.parse('{"ButtonSignOut":"Sign out","Delete":"Padam","LabelFinish":"Habis","LabelYoureDone":"Kamu Selesai!","ParentalRating":"Parental Rating","SettingsSaved":"Seting Disimpan","Absolute":"Mutlak","AccessRestrictedTryAgainLater":"Akses dihalang pada masa ini. Sila cuba sebentar lagi.","Actor":"Pelakon","Add":"Tambah","AddToCollection":"Tambah ke dalam koleksi","AddToPlayQueue":"Tambah ke giliran main","AddToPlaylist":"Tambah pada senarai main","AddedOnValue":"Tambahan {0}","AdditionalNotificationServices":"Semak imbas katalog plugin untuk memasang perkhidmatan pemberitahuan tambahan.","AirDate":"Tarikh siaran","Aired":"Disiarkan pada","All":"Semua","AllLibraries":"Semua pustaka","AllowMediaConversion":"Membolehkan penukaran media","AllowMediaConversionHelp":"Memberi atau menolak akses penukaran ciri media","Albums":"Album-album","Alerts":"Pemberitahuan","AllChannels":"Semua saluran","AllComplexFormats":"Semua format kompleks (ASS, SSA, VOBSUB, PGS, SUB/IDX, dll.)","AllEpisodes":"Semua episod","AllLanguages":"Semua bahasa","AllowOnTheFlySubtitleExtraction":"Membolehkan pengekstrakan sarikata serta-merta","AllowOnTheFlySubtitleExtractionHelp":"Sarikata-sarikata yang sedia ada dapat diekstrak dari video-video dan dihantar ke aplikasi Jellyfin dalam teks biasa. Ini untuk menghindari video daripada transkoding. Pada sistem-sistem lain, ia dapat mengambil masa panjang dan menyebabkan video main balik terhenti semasa proses pengekstrakan. Ciri ini dapat dimatikan supaya sarikata yang sedia ada akan dibakar bersama video transkoding, jika ianya tidak disokong secara asal oleh peranti klien.","AllowRemoteAccess":"Membenarkan persambungan jauh ke pelayan Jellyfin ini.","AllowRemoteAccessHelp":"Jika tidak disemak, semua persambungan jauh akan disekat.","AllowHWTranscodingHelp":"Benarkan penala untuk transkod strim serta-merta. Ini mungkin dapat bantu kurangkan kadar transkod yang diperlukan dari pelayan.","AlwaysPlaySubtitles":"Sentiasa main sarikata","AlwaysPlaySubtitlesHelp":"Sarikata sepadan dengan bahasa yang dipilih akan masih dimuatkan tanpa mengira bahasa audio.","AnyLanguage":"Mana-mana bahasa","Anytime":"Pada bila masa saja","AroundTime":"Sekitar {0}","Art":"Seni","Artists":"Artis","AsManyAsPossible":"Sebanyak mungkin","Ascending":"Susunan menaik","AspectRatio":"Nisbah aspek","Audio":"Audio","Auto":"Auto","Backdrop":"Latar belakang","Backdrops":"Latar belakang","BirthDateValue":"Lahir: {0}","BirthLocation":"Tempat lahir","BirthPlaceValue":"Tempat lahir: {0}","Blacklist":"Senarai hitam","Books":"Buku-buku","Box":"Kotak","Browse":"Semak imbas","ButtonAddMediaLibrary":"Tambah Pustaka Media","ButtonAddServer":"Tambah pelayan","ButtonAddUser":"Tambah pengguna","ButtonArrowLeft":"Kiri","ButtonArrowRight":"Kanan","ButtonAudioTracks":"Trek Audio","ButtonBack":"Kembali","ButtonCancel":"Batalkan","ButtonChangeServer":"Tukar pelayan","ButtonLibraryAccess":"Akses pustaka","ButtonInfo":"Info","ButtonGotIt":"Terima","ButtonFullscreen":"Paparan skrin penuh","ButtonForgotPassword":"Lupa Kata Laluan","ButtonEditOtherUserPreferences":"Edit profil, gambar dan keutamaan peribadi pengguna ini","ButtonAddScheduledTaskTrigger":"Tambah Pencetus","ButtonAddImage":"Tambah gambar","BurnSubtitlesHelp":"Menentukan sama ada pelayan perlu membakar subtitle ke skrin apabila menukar video bergantung kepada format sarikata. Menghindari pembakaran sari kata ke skrin akan meningkatkan prestasi pelayan. Pilih Auto untuk membakar format berasaskan imej (VOBSUB, PGS, SUB / IDX, dll) dan subtitle ASS / SSA tertentu.","MessageBrowsePluginCatalog":"Semak imbas katalog plugin kami untuk melihat plugin yang tersedia.","BoxRear":"Kotak (belakang)","BookLibraryHelp":"Buku audio dan teks disokong. Semak {0}panduan penamaan buku{1}.","Banner":"Sepanduk","AuthProviderHelp":"Pilih Pembekal Pengesahan yang akan digunakan untuk mengesahkan kata laluan pengguna ini.","AllowedRemoteAddressesHelp":"Senarai pemisah koma atau entri IP/netmask untuk rangkaian yang dibenarkan bagi menyambung secarajauh. Jika dibiarkan kosong, semua alamat jauh akan dibenarkan.","ValueSpecialEpisodeName":"Khas - {0}","HeaderContinueWatching":"Terus Menonton","Genres":"Genre-genre","Collections":"Koleksi","Channels":"Saluran","ButtonSyncPlay":"SyncPlay","Movies":"Filem","HeaderAlbumArtists":"Album Artis-artis","Folders":"Fail-fail","Favorites":"Kegemaran"}')}}]);