(self.webpackChunk=self.webpackChunk||[]).push([[7090],{39802:function(a){a.exports='<div id="wizardLibraryPage" data-role="page" class="page standalonePage wizardPage mediaLibraryPage"> <div class="padded-left padded-right padded-top"> <div class="ui-corner-all ui-shadow wizardContent"> <div> <h1 style="display:inline-block">${HeaderSetupLibrary}</h1> <a href="https://docs.jellyfin.org/general/server/libraries.html" rel="noopener noreferrer" target="_blank" class="clearLink" style="margin-top:-10px;display:inline-block;vertical-align:middle;margin-left:2em"><button is="emby-button" type="button" class="raised"><span class="material-icons info"></span><span>${Help}</span></button></a> </div> <br/> <div id="divVirtualFolders"></div> <br/> <br/> <div class="wizardNavigation"> <button is="emby-button" type="button" class="raised button-cancel" onclick="history.back()"> <span class="material-icons arrow_back"></span> <span>${Previous}</span> </button> <button is="emby-button" type="button" class="raised button-submit" onclick="WizardLibraryPage.next()"> <span>${Next}</span> <span class="material-icons arrow_forward"></span> </button> </div> </div> </div> </div> '}}]);