(self.webpackChunk=self.webpackChunk||[]).push([[809],{809:function(e){"use strict";e.exports=JSON.parse('{"TabLogs":"Capt\'n\'s Logs","HeaderAdmin":"Cap\'n","WelcomeToProject":"Ahoy, matey! This be Jellyfin!","ButtonOk":"Aye","DisplayInMyMedia":"Show on the Poop Deck","HeaderCastAndCrew":"Mateys","HeaderMusicQuality":"Sea Shanty Strength","HeaderLatestMusic":"Latest Sea Shanties","HeaderAudioBooks":"Spoken Tales","Books":"Tall Tales","LabelHomeNetworkQuality":"Sail strength:","Home":"Poop Deck","DisplayInOtherHomeScreenSections":"Show on Poop Deck such as latest booty and continue plundering","Add":"Upend","Actor":"Privateer","AccessRestrictedTryAgainLater":"Ye arn\'t appearin\' on the list o\' the livin\'!","ButtonSyncPlay":"SyncPlay","AddedOnValue":"Upended {0}","AddToCollection":"Add t\' ye collection","AdditionalNotificationServices":"Browse th\' plugin scroll t\' invoke additional bell-ringing.","AddToPlaylist":"Add t\' ye playlist","AddToPlayQueue":"Add t\' ye play queue","StopPlayback":"Belay That","ClearQueue":"Swab the Decks","Alerts":"Avast Ye","AirDate":"Maiden Voyage","SearchResults":"X Marks The Spot","Songs":"Shantees","SelectAdminUsername":"Capt\'n\'s Title.","OnWakeFromSleep":"Show A Leg","TabDashboard":"The Helm","TabContainers":"Chests","ValueOneSong":"1 shantee","ValueSongCount":"{0} shantees","Yes":"Ay","PathNotFound":"That Be Uncharted Waters Friend.","LastSeen":"Ship Last Sighted {0}","Aired":"Sailed"}')}}]);