(self.webpackChunk=self.webpackChunk||[]).push([[6337],{46337:function(e){"use strict";e.exports=JSON.parse('{"ButtonSyncPlay":"SyncPlay","AccessRestrictedTryAgainLater":"ابھی آپ یہ استعمال نہیں کر سکتے۔ کچھ دیر بعد کوشش کریںَ","Absolute":"سارا"}')}}]);