(self.webpackChunk=self.webpackChunk||[]).push([[8170],{99388:function(e,t,i){"use strict";i.r(t),i.d(t,{default:function(){return n}}),i(61013);var s=i(28469),a=i(6594);function n(e,t){e.addEventListener("viewbeforeshow",(function(){a.ZP.show();var t=ApiClient;t.getJSON(t.getUrl("System/Logs")).then((function(i){var n="";n+='<div class="paperList">',n+=i.map((function(e){var i=t.getUrl("System/Logs/Log",{name:e.Name}),a="";a+='<a is="emby-linkbutton" href="'+(i+="&api_key="+t.accessToken())+'" target="_blank" class="listItem listItem-border" style="color:inherit;">',a+='<div class="listItemBody two-line">',a+="<h3 class='listItemBodyText'>"+e.Name+"</h3>";var n=s.ZP.parseISO8601Date(e.DateModified,!0),r=s.ZP.toLocaleDateString(n);return a+='<div class="listItemBodyText secondary">'+(r+=" "+s.ZP.getDisplayTime(n))+"</div>",(a+="</div>")+"</a>"})).join(""),n+="</div>",e.querySelector(".serverLogs").innerHTML=n,a.ZP.hide()}))}))}i(78066),i(17734),i(93462)}}]);