(self.webpackChunk=self.webpackChunk||[]).push([[2005],{71477:function(s){s.exports='<div id="myPreferencesMenuPage" data-role="page" class="page libraryPage userPreferencesPage noSecondaryNavPage" data-title="${Settings}" data-backbutton="true"> <div class="padded-left padded-right padded-bottom-page padded-top"> <div class="readOnlyContent" style="margin:0 auto"> <div class="verticalSection verticalSection-extrabottompadding"> <h2 class="sectionTitle headerUsername" style="padding-left:.25em"></h2> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkMyProfile listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent person"></span> <div class="listItemBody"> <div class="listItemBodyText">${Profile}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkDisplayPreferences listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent tv"></span> <div class="listItemBody"> <div class="listItemBodyText">${Display}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkHomePreferences listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent home"></span> <div class="listItemBody"> <div class="listItemBodyText">${Home}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkPlaybackPreferences listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent play_circle_filled"></span> <div class="listItemBody"> <div class="listItemBodyText">${TitlePlayback}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkSubtitlePreferences listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent closed_caption"></span> <div class="listItemBody"> <div class="listItemBodyText">${Subtitles}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="lnkQuickConnectPreferences listItem-border hide"> <div class="listItem"> <em class="material-icons listItemIcon listItemIcon-transparent">tap_and_play</em> <div class="listItemBody"> <div class="listItemBodyText">${QuickConnect}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="clientSettings listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent devices_other"></span> <div class="listItemBody"> <div class="listItemBodyText">${ClientSettings}</div> </div> </div> </a> </div> <div class="adminSection verticalSection verticalSection-extrabottompadding hide"> <h2 class="sectionTitle" style="padding-left:.25em">${HeaderAdmin}</h2> <a is="emby-linkbutton" href="#!/dashboard.html" style="display:block;padding:0;margin:0" class="listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent dashboard"></span> <div class="listItemBody"> <div class="listItemBodyText">${TabDashboard}</div> </div> </div> </a> <a is="emby-linkbutton" href="#!/edititemmetadata.html" style="display:block;padding:0;margin:0" class="listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent mode_edit"></span> <div class="listItemBody"> <div class="listItemBodyText">${Metadata}</div> </div> </div> </a> </div> <div class="userSection verticalSection verticalSection-extrabottompadding"> <h2 class="sectionTitle" style="padding-left:.25em">${HeaderUser}</h2> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="selectServer hide listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent wifi"></span> <div class="listItemBody"> <div class="listItemBodyText">${SelectServer}</div> </div> </div> </a> <a is="emby-linkbutton" data-ripple="false" href="#" style="display:block;padding:0;margin:0" class="btnLogout listItem-border"> <div class="listItem"> <span class="material-icons listItemIcon listItemIcon-transparent exit_to_app"></span> <div class="listItemBody"> <div class="listItemBodyText">${ButtonSignOut}</div> </div> </div> </a> </div> </div> </div> </div> '}}]);