(self.webpackChunk=self.webpackChunk||[]).push([[8506],{58606:function(o,e,t){"use strict";var l=t(93476),r=t.n(l)()((function(o){return o[1]}));r.push([o.id,"#bookPlayer{position:relative;height:100%;width:100%;overflow:auto;z-index:100;background:#fff;display:-webkit-flex;display:flex;-webkit-flex-direction:column;flex-direction:column}#bookPlayer .topButtons{z-index:1002;position:absolute;top:0;width:100%;color:#000;opacity:.7}#bookPlayer .bookPlayerContainer{-webkit-flex-grow:1;flex-grow:1}#bookPlayer #btnBookplayerToc{float:left;margin-left:2vw}#bookPlayer #btnBookplayerExit{float:right;margin-right:2vw}#bookPlayer .bookplayerErrorMsg{text-align:center}#bookPlayer #btnBookplayerNext,#bookPlayer #btnBookplayerPrev{margin:.5vh}#dialogToc{background-color:#fff}#dialogToc .bookplayerButtonIcon{color:#000}#dialogToc .toc li{margin-bottom:5px}",""]),e.Z=r},61172:function(o,e,t){"use strict";t.r(e);var l=t(1892),r=t.n(l),a=t(58606);r()(a.Z,{insert:"head",singleton:!1}),e.default=a.Z.locals||{}}}]);