(self.webpackChunk=self.webpackChunk||[]).push([[9267],{69267:function(t){"use strict";t.exports=JSON.parse('{"ButtonOpen":"उघडा","ButtonOk":"ऑन","ButtonNextTrack":"पुढचा ट्रॅक","ButtonNetwork":"नेटवर्क","ButtonMore":"अजून","ButtonInfo":"माहिती","ButtonGotIt":"समजले","ButtonForgotPassword":"पासवर्ड विसरलो","ButtonChangeServer":"सर्व्हर बदला","ButtonCancel":"रद्द करा","ButtonBack":"मागे","ButtonAudioTracks":"ऑडिओ ट्रॅक","ButtonArrowRight":"उजवीकडे","ButtonArrowLeft":"डावीकडे","ButtonAddUser":"प्रयोक्ता जोडा","ButtonAddServer":"सर्व्हर जोडा","Books":"पुस्तकं","Blacklist":"ब्लॅकलिस्ट","BirthPlaceValue":"जन्म ठिकाण: {0}","BirthLocation":"जन्मस्थान","BirthDateValue":"जन्म: {0}","Backdrops":"पार्श्वभूमी","Backdrop":"पार्श्वभूमी","Auto":"आपोआप","Audio":"ऑडिओ","AspectRatio":"अ‍ॅस्पेक्ट रेशो","AsManyAsPossible":"जमतील तितके","Artists":"संगीतकार","Artist":"संगीतकार","Anytime":"कधीही","AnyLanguage":"कोणतीही भाषा","AlwaysPlaySubtitles":"नेहमीच प्ले करा","AllLibraries":"सर्व संग्रहालय","AllLanguages":"सर्व भाषा","AllEpisodes":"सर्व भाग","AllChannels":"सर्व वाहिन्या","All":"सर्व","Albums":"अल्बम","AlbumArtist":"अल्बम संगीतकार","Album":"अल्बम","AddedOnValue":"{0} जोडले","Add":"जोडा","Actor":"अभिनेता","EditSubtitles":"सबटायटल संपादित करा","EditMetadata":"मेटाडेटा संपादित करा","EditImages":"चित्र संपादित करा","Edit":"संपादित करा","DrmChannelsNotImported":"डी.आर.एम. असलेल्या वाहिन्या आयात केल्या जाणार नाहीत.","DownloadsValue":"{0} डाउनलोड","Download":"डाउनलोड","Down":"खाली","DoNotRecord":"रेकॉर्ड करू नका","Directors":"दिग्दर्शक","Director":"दिग्दर्शक","Desktop":"डेस्कटॉप","DeleteImageConfirmation":"तुम्हाला नक्की हे चित्र काढून टाकायचे आहे का?","Delete":"काढून टाका","DeleteImage":"चित्र काढून टाका","ConfirmEndPlayerSession":"{0} येथील जेलिफिन बंद करावे का?","Composer":"संगीत दिग्दर्शक","Channels":"वाहिन्या","ChannelNumber":"वाहिनी क्रमांक","Categories":"वर्ग","CancelRecording":"रेकॉर्डिंग रद्द करा","ButtonWebsite":"संकेतस्थळ","ButtonTrailer":"ट्रेलर","ButtonStop":"थांबा","ButtonStart":"सुरू करा","ButtonSend":"पाठवा","ButtonSelectView":"दृष्य निवडा","ButtonSelectDirectory":"डिरेक्टरी निवडा","ButtonScanAllLibraries":"सर्व संग्रहालय स्कॅन करा","ButtonRename":"नाव बदला","ButtonRemove":"काढून टाका","ButtonPreviousTrack":"मागचा ट्रॅक","ButtonPause":"पॉझ","ButtonSyncPlay":"SyncPlay","Collections":"संग्रह"}')}}]);