(self.webpackChunk=self.webpackChunk||[]).push([[2126],{6700:function(e,i,n){"use strict";var s=n(93476),t=n.n(s)()((function(e){return e[1]}));t.push([e.id,"#comicsPlayer .slideshowSwiperContainer{height:100%}#comicsPlayer .slider-zoom-container{text-align:center;height:100%}#comicsPlayer .swiper-slide-img{max-height:100%}",""]),i.Z=t},2462:function(e,i,n){"use strict";n.r(i);var s=n(1892),t=n.n(s),r=n(6700);t()(r.Z,{insert:"head",singleton:!1}),i.default=r.Z.locals||{}}}]);