(self.webpackChunk=self.webpackChunk||[]).push([[7523],{60157:function(a){a.exports='<div id="wizardStartPage" data-role="page" class="page standalonePage wizardPage"> <div class="padded-left padded-right padded-top"> <div class="ui-corner-all ui-shadow wizardContent" style="position:relative"> <form class="wizardStartForm"> <div> <h1 style="float:left">${WelcomeToProject}</h1> <a is="emby-linkbutton" rel="noopener noreferrer" href="https://docs.jellyfin.org/general/quick-start.html" target="_blank" class="raised raised-alt" style="float:right;margin-top:20px"> <span>${ButtonQuickStartGuide}</span> </a> </div> <br style="clear:both"/> <p>${ThisWizardWillGuideYou}</p> <br/> <div class="selectContainer"> <select is="emby-select" id="selectLocalizationLanguage" label="${LabelPreferredDisplayLanguage}"></select> </div> <br/> <div class="wizardNavigation" style="text-align:right"> <button is="emby-button" type="submit" class="raised button-submit"> <span>${Next}</span> <span class="material-icons arrow_forward"></span> </button> </div> </form> </div> </div> </div> '}}]);