(self.webpackChunk=self.webpackChunk||[]).push([[7763],{77237:function(n,t,o){"use strict";var i=o(93476),e=o.n(i)()((function(n){return n[1]}));e.push([n.id,"#pdfPlayer{position:relative;height:100%;width:100%;overflow:none;z-index:100;background:#fff}#canvas{display:block;margin:auto}.actionButtons{right:.5vh;top:.5vh;z-index:1002;position:absolute}.actionButtonIcon{color:#000;opacity:.7}",""]),t.Z=e},98986:function(n,t,o){"use strict";o.r(t);var i=o(1892),e=o.n(i),a=o(77237);e()(a.Z,{insert:"head",singleton:!1}),t.default=a.Z.locals||{}}}]);