(self.webpackChunk=self.webpackChunk||[]).push([[704],{46587:function(i){i.exports='<div id="serverActivityPage" data-role="page" class="page type-interior serverActivityPage noSecondaryNavPage" data-title="${HeaderActivity}"> <div> <div class="content-primary"> <div class="verticalSection"> <h2 class="sectionTitle"></h2> </div> <div class="readOnlyContent"> <div class="paperList activityItems" data-activitylimit="100"></div> </div> </div> </div> </div> '}}]);