(self.webpackChunk=self.webpackChunk||[]).push([[6152],{86022:function(e){e.exports='<div id="liveTvGuideProviderPage" data-role="page" class="page type-interior liveTvSettingsPage"> <div> <div class="content-primary"> <div class="readOnlyContent providerTemplate" style="margin-top:2em"></div> </div> </div> </div> '}}]);