(self.webpackChunk=self.webpackChunk||[]).push([[4742],{6453:function(o){o.exports='<div class="topButtons"> <button is="paper-icon-button-light" id="btnBookplayerToc" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon toc"></span> </button> <button is="paper-icon-button-light" id="btnBookplayerExit" class="autoSize bookplayerButton hide-mouse-idle-tv" tabindex="-1"> <span class="material-icons bookplayerButtonIcon close"></span> </button> </div> <div id="bookPlayerContainer" class="bookPlayerContainer"></div> '}}]);