(self.webpackChunk=self.webpackChunk||[]).push([[6597],{68537:function(e,r,t){"use strict";t.r(r),t.d(r,{default:function(){return s}});var n=t(61097),i=t(17146),a=t(6594);t(21865),t(78066);var o={SortBy:"SortName",SortOrder:"Ascending"};function s(e,r,t){var s;this.preRender=function(){s=ApiClient.getLiveTvSeriesTimers(o)},this.renderTab=function(){var e,r;e=t,r=s,a.ZP.show(),r.then((function(r){!function(e,r){var t=n.default.getCardsHtml({items:r,shape:"auto",defaultShape:"portrait",showTitle:!0,cardLayout:!1,preferThumb:"auto",coverImage:!0,overlayText:!1,showSeriesTimerTime:!0,showSeriesTimerChannel:!0,centerText:!0,overlayMoreButton:!0,lines:3}),o=e.querySelector("#items");o.innerHTML=t,i.default.lazyChildren(o),a.ZP.hide()}(e,r.Items)}))}}}}]);