(self.webpackChunk=self.webpackChunk||[]).push([[9655],{57870:function(i){i.exports='<div id="pluginsPage" data-role="page" class="page type-interior pluginConfigurationPage withTabs fullWidthContent"> <div> <div class="content-primary"> <div class="installedPlugins"></div> </div> </div> </div> '}}]);