(self.webpackChunk=self.webpackChunk||[]).push([[3273],{3273:function(e){"use strict";e.exports=JSON.parse('{"ButtonCancel":"Адмяніць","ButtonOk":"ОК","ButtonQuickStartGuide":"Кіраўніцтва па запуску","ButtonSignOut":"Sign out","HeaderEasyPinCode":"Просты PIN-код","HeaderPaths":"Шляхі","HeaderTaskTriggers":"Трыгеры задачы","LabelFinish":"Гатова","LabelYoureDone":"Вы скончылі!","MoreUsersCanBeAddedLater":"Потым можна дадаць яшчэ карыстальнікаў праз «Інфапанэль».","TellUsAboutYourself":"Раскажыце пра сябе","ThisWizardWillGuideYou":"Гэты памочнік правядзе вас праз усе фазы ўстаноўкі і налады. Спачатку абярыце упадабаную мову.","UserProfilesIntro":"У Jellyfin існуе ўбудаваная падтрымка для карыстальніцкіх профіляў, дазваляючы кожнаму карыстальніку валодаць сваімі ўласнымі параметрамі адлюстравання, станам прайгравання і кіраваннем ўтрымання.","WelcomeToProject":"Пачатак працы ў Jellyfin!","WizardCompleted":"Гэта ўсё, што нам трэба зараз. Jellyfin пачынае збіраць звесткі аб вашай медыятэцы. Азнаёмцеся пакуль з некаторымі нашымі праграмамі, а затым націсніце  <b>Гатова</b>, каб праглядзець <b>Инфопанель сервера</b>.","ButtonSyncPlay":"SyncPlay"}')}}]);