(self.webpackChunk=self.webpackChunk||[]).push([[4316],{44316:function(e,n,s){"use strict";s.r(n);var i,o,t,r,a,c,d=s(47005),u=s(53218),l=s(83094),f=s(47518);function m(){this.classList.add("hide")}function v(){c&&(clearTimeout(c),c=null)}function h(){v();var e=o;e&&(a?(e.offsetWidth,requestAnimationFrame((function(){e.classList.add("iconOsd-hidden"),l.ZP.addEventListener(e,l.ZP.whichTransitionEvent(),m,{once:!0})}))):m.call(e))}function p(e){var n,s,i;(n=o)||(a=f.Z.supportsCssAnimation(),(n=document.createElement("div")).classList.add("hide"),n.classList.add("iconOsd"),n.classList.add("iconOsd-hidden"),n.classList.add("volumeOsd"),n.innerHTML='<span class="material-icons iconOsdIcon volume_up"></span><div class="iconOsdProgressOuter"><div class="iconOsdProgressInner"></div></div>',t=n.querySelector(".material-icons"),r=n.querySelector(".iconOsdProgressInner"),document.body.appendChild(n),o=n),s=this.isMuted(),i=this.getVolume(),t&&(t.classList.remove("volume_off","volume_up"),t.classList.add(s?"volume_off":"volume_up")),r&&(r.style.width=(i||0)+"%"),function(){v();var e=o;l.ZP.removeEventListener(e,l.ZP.whichTransitionEvent(),m,{once:!0}),e.classList.remove("hide"),e.offsetWidth,requestAnimationFrame((function(){e.classList.remove("iconOsd-hidden"),c=setTimeout(h,3e3)}))}()}function g(e){e!==i&&(function(){var e=i;e&&(d.Events.off(e,"volumechange",p),d.Events.off(e,"playbackstop",h),i=null)}(),i=e,e&&(h(),d.Events.on(e,"volumechange",p),d.Events.on(e,"playbackstop",h)))}s(61866),s(56561),d.Events.on(u.O,"playerchange",(function(){g(u.O.getCurrentPlayer())})),g(u.O.getCurrentPlayer())},50183:function(e,n,s){"use strict";var i=s(93476),o=s.n(i)()((function(e){return e[1]}));o.push([e.id,".iconOsd{position:fixed;top:7%;right:3%;z-index:100000;background:#222;background:rgba(0,0,0,.8);padding:1em;color:#fff;-webkit-backdrop-filter:blur(5px);backdrop-filter:blur(5px);border-radius:.25em;transition:opacity .2s ease-out}.iconOsd-hidden{opacity:0}.iconOsdIcon{font-size:320%;display:block;margin:.25em .7em}.iconOsdProgressOuter{margin:1.5em .25em 1em;height:.35em;background:#222;border-radius:.25em}.iconOsdProgressInner{background:#00a4dc;height:100%;border-radius:.25em}.brightnessOsdProgressInner{background:#ff9800}",""]),n.Z=o},61866:function(e,n,s){"use strict";var i=s(1892),o=s.n(i),t=s(50183);o()(t.Z,{insert:"head",singleton:!1}),t.Z.locals}}]);