(self.webpackChunk=self.webpackChunk||[]).push([[9661],{801:function(e,t,s){"use strict";s.r(t),s.d(t,{default:function(){return i}});var r=s(53754),n=s(76543);function a(e){if(e.Success){var t=r.ZP.translate("MessagePasswordResetForUsers");return t+="<br/>",t+="<br/>",t+=e.UsersReset.join("<br/>"),void n.ZP.alert({message:t,title:r.ZP.translate("HeaderPasswordReset"),callback:function(){window.location.href="index.html"}})}n.ZP.alert({message:r.ZP.translate("MessageInvalidForgotPasswordPin"),title:r.ZP.translate("HeaderPasswordReset")})}function i(e,t){e.querySelector("form").addEventListener("submit",(function(t){return ApiClient.ajax({type:"POST",url:ApiClient.getUrl("Users/ForgotPassword/Pin"),dataType:"json",data:JSON.stringify({Pin:e.querySelector("#txtPin").value}),contentType:"application/json"}).then(a),t.preventDefault(),!1}))}}}]);