(self.webpackChunk=self.webpackChunk||[]).push([[8815],{99799:function(a){a.exports='<div id="editItemMetadataPage" data-role="page" class="page libraryPage metadataEditorPage noSecondaryNavPage" data-title="${MetadataManager}"> <style>#editItemMetadataPage .editMetadataForm{max-width:100%}</style> <div class="editPageSidebar" style="overflow:auto"> <div class="libraryTree"> <ul></ul> </div> </div> <div> <div class="editPageInnerContent padded-top padded-bottom-page"> </div> </div> </div> '}}]);