(self.webpackChunk=self.webpackChunk||[]).push([[6860],{96860:function(e,t,r){"use strict";r.r(t),r.d(t,{deleteItem:function(){return l}}),r(63238),r(61418);var n=r(56346),a=r(6383),u=r(53754),i=r(53913),o=r(61642);function l(e){var t=e.item,r=t.SeasonId||t.SeriesId||t.ParentId,l=i.ZP.getApiClient(t.ServerId);return(0,n.Z)({title:u.ZP.translate("HeaderDeleteItem"),text:u.ZP.translate("ConfirmDeleteItem"),confirmText:u.ZP.translate("Delete"),primary:"delete"}).then((function(){return l.deleteItem(t.Id).then((function(){e.navigate&&(r?a.appRouter.showItem(r,t.ServerId):a.appRouter.goHome())}),(function(e){var t=function(){return Promise.reject(e)};return function(e){return(0,o.Z)(e)}(u.ZP.translate("ErrorDeletingItem")).then(t,t)}))}))}t.default={deleteItem:l}}}]);