(self.webpackChunk=self.webpackChunk||[]).push([[7563],{7907:function(e,t,n){"use strict";var i=n(93476),h=n.n(i)()((function(e){return e[1]}));h.push([e.id,"@media (min-height:720px){html{font-size:20px}}@media (min-height:1000px){html{font-size:27px}}h1{font-weight:400;font-size:1.8em}.layout-desktop h1{font-size:2em}h2{font-size:1.8em}h2,h3{font-weight:400}h3{font-size:1.17em}",""]),t.Z=h},37563:function(e,t,n){"use strict";n.r(t);var i=n(1892),h=n.n(i),s=n(7907);h()(s.Z,{insert:"head",singleton:!1}),t.default=s.Z.locals||{}}}]);