(self.webpackChunk=self.webpackChunk||[]).push([[6777],{29873:function(t,e,r){"use strict";function a(){var t,e=this;function a(){var t,e=[o,n,s,f,i,d,c],r=document.querySelector(".logoScreenSaverImage");r&&r.animate&&e[(0,t=e.length-1,Math.floor(Math.random()*(t-0+1))+0)](r,1)}function o(t,e){var r={duration:900,iterations:e,easing:"cubic-bezier(0.215, 0.610, 0.355, 1.000)"};return t.animate([{transform:"translate3d(-3000px, 0, 0)",opacity:"0",offset:0},{transform:"translate3d(25px, 0, 0)",opacity:"1",offset:.6},{transform:"translate3d(-100px, 0, 0)",offset:.75},{transform:"translate3d(5px, 0, 0)",offset:.9},{transform:"none",opacity:"1",offset:1}],r)}function n(t,e){var r={duration:900,iterations:e,easing:"cubic-bezier(0.215, 0.610, 0.355, 1.000)"};return t.animate([{transform:"translate3d(3000px, 0, 0)",opacity:"0",offset:0},{transform:"translate3d(-25px, 0, 0)",opacity:"1",offset:.6},{transform:"translate3d(100px, 0, 0)",offset:.75},{transform:"translate3d(-5px, 0, 0)",offset:.9},{transform:"none",opacity:"1",offset:1}],r)}function s(t,e){var r={duration:900,iterations:e};return t.animate([{transform:"translate(0%)",offset:0},{transform:"rotate3d(0, 0, 1, 15deg)",offset:.2},{transform:"rotate3d(0, 0, 1, -10deg)",offset:.4},{transform:"rotate3d(0, 0, 1, 5deg)",offset:.6},{transform:"rotate3d(0, 0, 1, -5deg)",offset:.8},{transform:"rotate3d(0, 0, 1, 0deg)",offset:1}],r)}function f(t,e){var r={duration:900,iterations:e};return t.animate([{transform:"scale3d(1, 1, 1)",offset:0},{transform:"scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg)",offset:.1},{transform:"scale3d(.9, .9, .9) rotate3d(0, 0, 1, -3deg)",offset:.2},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)",offset:.3},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg)",offset:.4},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)",offset:.5},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg)",offset:.6},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)",offset:.7},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg)",offset:.8},{transform:"scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg)",offset:.9},{transform:"scale3d(1, 1, 1)",offset:1}],r)}function i(t,e){var r={duration:900,iterations:e};return t.animate([{transform:"translate(0%)",offset:0},{transform:"translate3d(20%, 0, 0) rotate3d(0, 0, 1, 3deg)",offset:.15},{transform:"translate3d(-15%, 0, 0) rotate3d(0, 0, 1, -3deg)",offset:.45},{transform:"translate3d(10%, 0, 0) rotate3d(0, 0, 1, 2deg)",offset:.6},{transform:"translate3d(-5%, 0, 0) rotate3d(0, 0, 1, -1deg)",offset:.75},{transform:"translateX(0%)",offset:1}],r)}function d(t,e){var r={duration:900,iterations:e};return t.animate([{transform:"rotate3d(0, 0, 1, -200deg)",opacity:"0",transformOrigin:"center",offset:0},{transform:"none",opacity:"1",transformOrigin:"center",offset:1}],r)}function c(t,e){var r={duration:900,iterations:e};return t.animate([{transform:"none",opacity:"1",transformOrigin:"center",offset:0},{transform:"rotate3d(0, 0, 1, 200deg)",opacity:"0",transformOrigin:"center",offset:1}],r)}function m(){t&&(clearInterval(t),t=null)}e.name="Logo ScreenSaver",e.type="screensaver",e.id="logoscreensaver",e.supportsAnonymous=!0,e.show=function(){r.e(7111).then(r.bind(r,15535)).then((function(){var e=document.querySelector(".logoScreenSaver");e||((e=document.createElement("div")).classList.add("logoScreenSaver"),document.body.appendChild(e),e.innerHTML='<img class="logoScreenSaverImage" src="assets/img/banner-light.png" />'),m(),t=setInterval(a,3e3)}))},e.hide=function(){m();var t=document.querySelector(".logoScreenSaver");return t?new Promise((function(e){var r=function(){t.parentNode.removeChild(t),e()};t.animate?(function(t,e){var r={duration:400,iterations:1};return t.animate([{opacity:"1",offset:0},{opacity:"0",offset:1}],r)}(t)).onfinish=r:r()})):Promise.resolve()}}r.r(e),r.d(e,{default:function(){return a}}),r(63238),r(61418),r(5769)}}]);