(self.webpackChunk=self.webpackChunk||[]).push([[8269],{78269:function(s){"use strict";s.exports=JSON.parse('{"AllowMediaConversion":"Permitir a conversión dos medios","AllComplexFormats":"Todos os formatos complexos (ASS, SSA, VOBSUB, PGS, SUB/IDX, etc.)","AllLibraries":"Todas as librarías","AllLanguages":"Todas as linguas","AllEpisodes":"Todos os episodios","All":"Todo","Albums":"Álbumes","Alerts":"Avisos","AllChannels":"Todos os canais","AirDate":"Data de emisión","Aired":"Emitido","AddToPlaylist":"Engadir á lista de reprodución","Add":"Engadir","ButtonSyncPlay":"SyncPlay","Collections":"Colecións","Channels":"Canles","Books":"Libros","Artists":"Artistas","Absolute":""}')}}]);