(self.webpackChunk=self.webpackChunk||[]).push([[5785],{62015:function(e){e.exports='<div id="logPage" data-role="page" class="page type-interior"> <div> <div class="content-primary"> <div class="serverLogs readOnlyContent"> </div> </div> </div> </div> '}}]);