(self.webpackChunk=self.webpackChunk||[]).push([[8019],{40087:function(e,t,n){"use strict";n.r(t),n(63238),n(61418),n(5769);var r=n(47005),o=n(6594),i=n(53754),u=n(76543);function a(){u.ZP.navigate("livetvstatus.html")}(0,u.Xz)("pageshow","liveTvGuideProviderPage",(function(){o.ZP.show();var e=getParameterByName("id");!function(e,t,o){n(85624)("./".concat(t,".template.html")).then((function(u){var c=u.default;e.querySelector(".providerTemplate").innerHTML=i.ZP.translateHtml(c),function(e,t,o){n(71718)("./".concat(t)).then((function(t){var n=new(0,t.default)(e,o,{});r.Events.on(n,"submitted",a),n.init()}))}(e,t,o)}))}(this,getParameterByName("type"),e)}))},71718:function(e,t,n){var r={"./schedulesdirect":[42014,9,2014],"./schedulesdirect.js":[42014,9,2014],"./schedulesdirect.template.html":[36787,7,6787],"./xmltv":[52966,9,2966],"./xmltv.js":[52966,9,2966],"./xmltv.template.html":[94503,7,4503]};function o(e){if(!n.o(r,e))return Promise.resolve().then((function(){var t=new Error("Cannot find module '"+e+"'");throw t.code="MODULE_NOT_FOUND",t}));var t=r[e],o=t[0];return n.e(t[2]).then((function(){return n.t(o,16|t[1])}))}o.keys=function(){return Object.keys(r)},o.id=71718,e.exports=o},85624:function(e,t,n){var r={"./schedulesdirect.template.html":[36787,6787],"./xmltv.template.html":[94503,4503]};function o(e){if(!n.o(r,e))return Promise.resolve().then((function(){var t=new Error("Cannot find module '"+e+"'");throw t.code="MODULE_NOT_FOUND",t}));var t=r[e],o=t[0];return n.e(t[1]).then((function(){return n.t(o,7)}))}o.keys=function(){return Object.keys(r)},o.id=85624,e.exports=o}}]);