(self.webpackChunk=self.webpackChunk||[]).push([[9200],{70869:function(e){e.exports='<div id="metadataImagesConfigurationPage" data-role="page" class="page type-interior metadataConfigurationPage withTabs"> <div> <div class="content-primary"> <form class="metadataImagesConfigurationForm"> <h2 style="margin-top:0">${HeaderPreferredMetadataLanguage}</h2> <p style="margin:1.5em 0">${DefaultMetadataLangaugeDescription}</p> <div class="selectContainer"> <select is="emby-select" id="selectLanguage" required="required" label="${LabelLanguage}"></select> </div> <div class="selectContainer"> <select is="emby-select" id="selectCountry" required="required" label="${LabelCountry}"></select> </div> <br/> <div><button is="emby-button" type="submit" class="raised button-submit block"><span>${Save}</span></button></div> </form> </div> </div> </div> '}}]);