(self.webpackChunk=self.webpackChunk||[]).push([[4919],{22450:function(a){a.exports='<div id="searchPage" data-role="page" class="page libraryPage allLibraryPage noSecondaryNavPage" data-title="${Search}" data-backbutton="true"> <div class="padded-left padded-right searchFields"></div> <div class="searchResults padded-bottom-page padded-top"></div> </div> '}}]);