(self.webpackChunk=self.webpackChunk||[]).push([[8951],{59092:function(e,t,i){"use strict";var r=i(93476),o=i.n(r)()((function(e){return e[1]}));o.push([e.id,".editPageSidebar{display:block}.editPageSidebar-withcontent{display:none}.libraryTree{margin-left:.25em}.offlineEditorNode{color:#c33}.editorNode img{height:18px;margin:0 .35em;vertical-align:middle;position:relative;top:-2px}.jstree-anchor{font-weight:400!important}.jstree-wholerow-hovered{background:#38c!important;border-radius:0!important;box-shadow:none!important}.jstree-default .jstree-hovered{background:0 0!important;border-radius:0!important;box-shadow:none!important;color:#fff!important}.jstree-default .jstree-wholerow-clicked{background:#00a4dc!important}.metadataSidebarIcon{margin-right:.4em}@media (min-width:50em){.editPageSidebar{position:fixed;top:5.2em;bottom:0;left:0;width:30%;border-right:1px solid #555;display:block}.editPageInnerContent{float:right;width:68.5%}}@media (min-width:112.5em){.editPageSidebar{width:25%}.editPageInnerContent{width:73.5%}}",""]),t.Z=o},68951:function(e,t,i){"use strict";i.r(t);var r=i(1892),o=i.n(r),a=i(59092);o()(a.Z,{insert:"head",singleton:!1}),t.default=a.Z.locals||{}}}]);