(self.webpackChunk=self.webpackChunk||[]).push([[302],{70302:function(e){"use strict";e.exports=JSON.parse('{"AddToPlayQueue":"เพิ่มไปยังคิวเล่น","AddToCollection":"เพิ่มไปยังคอลเลกชัน","Add":"เพิ่ม","Actor":"นักแสดง","AccessRestrictedTryAgainLater":"ขณะนี้การเข้าถึงถูกจำกัด โปรดลองอีกครั้งในภายหลัง","Absolute":"แน่นอน","RemoveFromPlaylist":"ลบออกจากเพลย์ลิสต์","Playlists":"เพลย์ลิสต์","LabelPlaylist":"เพลย์ลิสต์:","HeaderAddToPlaylist":"เพิ่มไปยังเพลย์ลิสต์","ButtonTogglePlaylist":"เพลย์ลิสต์","AddToPlaylist":"เพิ่มไปยังเพลย์ลิสต์"}')}}]);