(self.webpackChunk=self.webpackChunk||[]).push([[3320],{68315:function(e){e.exports='<div id="libraryDisplayPage" data-role="page" class="page type-interior librarySectionPage withTabs"> <div> <div class="content-primary"> <form> <div class="selectContainer"> <select is="emby-select" id="selectDateAdded" data-mini="true" label="${LabelDateAddedBehavior}"> <option value="0">${OptionDateAddedImportTime}</option> <option value="1">${OptionDateAddedFileTime}</option> </select> <div class="fieldDescription">${LabelDateAddedBehaviorHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" class="chkFolderView"/> <span>${OptionDisplayFolderView}</span> </label> <div class="fieldDescription checkboxFieldDescription">${OptionDisplayFolderViewHelp}</div> </div> <label class="checkboxContainer"> <input type="checkbox" is="emby-checkbox" class="chkDisplaySpecialsWithinSeasons"/> <span>${LabelDisplaySpecialsWithinSeasons}</span> </label> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" class="chkGroupMoviesIntoCollections"/> <span>${LabelGroupMoviesIntoCollections}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelGroupMoviesIntoCollectionsHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input class="chkExternalContentInSuggestions" type="checkbox" is="emby-checkbox"/> <span>${OptionEnableExternalContentInSuggestions}</span> </label> <div class="fieldDescription checkboxFieldDescription">${OptionEnableExternalContentInSuggestionsHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription fldSaveMetadataHidden hide"> <label> <input type="checkbox" is="emby-checkbox" class="chkAirDays" id="chkSaveMetadataHidden" data-filter="Sunday"/> <span>${OptionSaveMetadataAsHidden}</span> </label> <div class="fieldDescription checkboxFieldDescription">${OptionSaveMetadataAsHiddenHelp}</div> </div> <br/> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </form> </div> </div> </div> '}}]);