(self.webpackChunk=self.webpackChunk||[]).push([[7057],{17057:function(e,t,r){"use strict";r.r(t);var n=r(66056);window.PlaylistViewer={render:function(e,t){e.playlistInit||(e.playlistInit=!0,function(e,t){var r,i=e.querySelector("#childrenContent .itemsContainer");i.classList.add("vertical-list"),i.classList.remove("vertical-wrap"),i.enableDragReordering(!0),i.fetchData=(r=t.Id,function(){var e={Fields:"PrimaryImageAspectRatio",EnableImageTypes:"Primary,Backdrop,Banner,Thumb",UserId:ApiClient.getCurrentUserId()};return ApiClient.getJSON(ApiClient.getUrl("Playlists/".concat(r,"/Items"),e))}),i.getItemsHtml=function(e){return function(t){return n.Z.getListViewHtml({items:t,showIndex:!1,showRemoveFromPlaylist:!0,playFromHere:!0,action:"playallfromhere",smallIcon:!0,dragHandle:!0,playlistId:e})}}(t.Id)}(e,t)),e.querySelector("#childrenContent").classList.add("verticalSection-extrabottompadding"),e.querySelector("#childrenContent .itemsContainer").refreshItems()}}}}]);