(self.webpackChunk=self.webpackChunk||[]).push([[7375],{92322:function(e,t,n){"use strict";n.r(t),n.d(t,{default:function(){return r}});var i=n(6594);function u(){i.ZP.show(),ApiClient.ajax({url:ApiClient.getUrl("Startup/Complete"),type:"POST"}).then((function(){i.ZP.hide(),window.location.href="index.html"}))}function r(e,t){e.querySelector(".btnWizardNext").addEventListener("click",u)}}}]);