(self.webpackChunk=self.webpackChunk||[]).push([[2434],{61203:function(e){e.exports='<div id="wizardSettingsPage" data-role="page" class="page standalonePage wizardPage"> <div class="padded-left padded-right padded-top"> <div class="ui-corner-all ui-shadow wizardContent"> <form class="wizardSettingsForm"> <h1>${HeaderConfigureRemoteAccess}</h1> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkRemoteAccess" checked="checked"/> <span>${AllowRemoteAccess}</span> </label> <div class="fieldDescription checkboxFieldDescription">${AllowRemoteAccessHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnableUpnp"/> <span>${LabelEnableAutomaticPortMap}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelEnableAutomaticPortMapHelp}</div> </div> <br/> <div class="wizardNavigation"> <button is="emby-button" type="button" class="raised button-cancel" onclick="history.back()"> <span class="material-icons arrow_back"></span> <span>${Previous}</span> </button> <button is="emby-button" type="submit" class="raised button-submit"> <span>${Next}</span> <span class="material-icons arrow_forward"></span> </button> </div> </form> </div> </div> </div> '}}]);