(self.webpackChunk=self.webpackChunk||[]).push([[6245],{18103:function(e,t,r){"use strict";r.r(t),r.d(t,{default:function(){return c}});var n=r(6594),a=r(53754),o=(r(65183),r(30983),r(78066),r(76543)),u=r(38440);function s(){return ApiClient}function i(e){console.debug("user update complete: "+e),n.ZP.hide(),o.ZP.navigate("wizardlibrary.html")}function l(e){var t=this;return t.querySelector("#txtManualPassword").value!=t.querySelector("#txtPasswordConfirm").value?(0,u.Z)(a.ZP.translate("PasswordMatchError")):function(e){n.ZP.show();var t=s();t.ajax({type:"POST",data:JSON.stringify({Name:e.querySelector("#txtUsername").value,Password:e.querySelector("#txtManualPassword").value}),url:t.getUrl("Startup/User"),contentType:"application/json"}).then(i)}(t),e.preventDefault(),!1}function d(){n.ZP.show();var e=this,t=s();t.getJSON(t.getUrl("Startup/User")).then((function(t){e.querySelector("#txtUsername").value=t.Name||"",e.querySelector("#txtManualPassword").value=t.Password||"",n.ZP.hide()}))}function c(e,t){e.querySelector(".wizardUserForm").addEventListener("submit",l),e.addEventListener("viewshow",(function(){document.querySelector(".skinHeader").classList.add("noHomeButtonHeader")})),e.addEventListener("viewhide",(function(){document.querySelector(".skinHeader").classList.remove("noHomeButtonHeader")})),e.addEventListener("viewshow",d)}}}]);