(self.webpackChunk=self.webpackChunk||[]).push([[4258],{11142:function(t,r,n){"use strict";n.d(r,{Z:function(){return D}});var a=n(85847),e=n(24700);function o(t,r){(0,e.Z)(2,arguments);var n=(0,a.Z)(t),o=(0,a.Z)(r),i=n.getTime()-o.getTime();return i<0?-1:i>0?1:i}function i(t,r){(0,e.Z)(2,arguments);var n=(0,a.Z)(t),o=(0,a.Z)(r),i=n.getFullYear()-o.getFullYear(),u=n.getMonth()-o.getMonth();return 12*i+u}function u(t,r){(0,e.Z)(2,arguments);var n=(0,a.Z)(t),u=(0,a.Z)(r),s=o(n,u),f=Math.abs(i(n,u));n.setMonth(n.getMonth()-s*f);var c=o(n,u)===-s,l=s*(f-c);return 0===l?0:l}function s(t,r){(0,e.Z)(2,arguments);var n=(0,a.Z)(t),o=(0,a.Z)(r);return n.getTime()-o.getTime()}function f(t,r){(0,e.Z)(2,arguments);var n=s(t,r)/1e3;return n>0?Math.floor(n):Math.ceil(n)}var c=n(35997);function l(t){return function(t,r){if(null==t)throw new TypeError("assign requires that input parameter not be null or undefined");for(var n in r=r||{})r.hasOwnProperty(n)&&(t[n]=r[n]);return t}({},t)}var h=n(63874),m=1440,Z=43200;function D(t,r,n){(0,e.Z)(2,arguments);var i=n||{},s=i.locale||c.Z;if(!s.formatDistance)throw new RangeError("locale must contain formatDistance property");var D=o(t,r);if(isNaN(D))throw new RangeError("Invalid time value");var v,M,d=l(i);d.addSuffix=Boolean(i.addSuffix),d.comparison=D,D>0?(v=(0,a.Z)(r),M=(0,a.Z)(t)):(v=(0,a.Z)(t),M=(0,a.Z)(r));var g,X=f(M,v),p=((0,h.Z)(M)-(0,h.Z)(v))/1e3,w=Math.round((X-p)/60);if(w<2)return i.includeSeconds?X<5?s.formatDistance("lessThanXSeconds",5,d):X<10?s.formatDistance("lessThanXSeconds",10,d):X<20?s.formatDistance("lessThanXSeconds",20,d):X<40?s.formatDistance("halfAMinute",null,d):X<60?s.formatDistance("lessThanXMinutes",1,d):s.formatDistance("xMinutes",1,d):0===w?s.formatDistance("lessThanXMinutes",1,d):s.formatDistance("xMinutes",w,d);if(w<45)return s.formatDistance("xMinutes",w,d);if(w<90)return s.formatDistance("aboutXHours",1,d);if(w<m){var T=Math.round(w/60);return s.formatDistance("aboutXHours",T,d)}if(w<2520)return s.formatDistance("xDays",1,d);if(w<Z){var b=Math.round(w/m);return s.formatDistance("xDays",b,d)}if(w<86400)return g=Math.round(w/Z),s.formatDistance("aboutXMonths",g,d);if((g=u(M,v))<12){var x=Math.round(w/Z);return s.formatDistance("xMonths",x,d)}var S=g%12,y=Math.floor(g/12);return S<3?s.formatDistance("aboutXYears",y,d):S<9?s.formatDistance("overXYears",y,d):s.formatDistance("almostXYears",y+1,d)}},19502:function(t,r,n){"use strict";n.d(r,{Z:function(){return o}});var a=n(11142),e=n(24700);function o(t,r){return(0,e.Z)(1,arguments),(0,a.Z)(t,Date.now(),r)}}}]);