(self.webpackChunk=self.webpackChunk||[]).push([[5554],{98726:function(e){e.exports='<div id="quickConnectPage" data-role="page" class="page type-interior advancedConfigurationPage"> <div class="content-primary"> <form class="quickConnectSettings"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${QuickConnect}</h2> </div> </div> <div>${LabelCurrentStatus}<span id="quickConnectStatus" style="padding:0 .4em"></span></div> <div class="checkboxList paperList" style="padding:.5em 1em"> <label> <input type="checkbox" is="emby-checkbox" id="chkQuickConnectAvailable"/> <span>${EnableQuickConnect}</span> </label> </div> <button is="emby-button" id="btnQuickConnectSubmit" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </form> </div> </div> '}}]);