(self.webpackChunk=self.webpackChunk||[]).push([[5421],{30267:function(e){e.exports='<div id="metadataNfoPage" data-role="page" class="page type-interior metadataConfigurationPage withTabs"> <div> <div class="content-primary"> <form class="metadataNfoForm"> <p>${HeaderKodiMetadataHelp}</p> <br/> <div class="selectContainer"> <select is="emby-select" name="selectUser" id="selectUser" label="${LabelKodiMetadataUser}"></select> <div class="fieldDescription">${LabelKodiMetadataUserHelp}</div> </div> <div class="selectContainer"> <select is="emby-select" name="selectReleaseDateFormat" id="selectReleaseDateFormat" label="${LabelKodiMetadataDateFormat}"> <option value="yyyy-MM-dd">yyyy-MM-dd</option> </select> <div class="fieldDescription">${LabelKodiMetadataDateFormatHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkSaveImagePaths"/> <span>${LabelKodiMetadataSaveImagePaths}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelKodiMetadataSaveImagePathsHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnablePathSubstitution"/> <span>${LabelKodiMetadataEnablePathSubstitution}</span> </label> <div class="fieldDescription checkboxFieldDescription"> <div>${LabelKodiMetadataEnablePathSubstitutionHelp}</div> </div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnableExtraThumbs"/> <span>${LabelKodiMetadataEnableExtraThumbs}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelKodiMetadataEnableExtraThumbsHelp}</div> </div> <div><button is="emby-button" type="submit" class="raised button-submit block"><span>${Save}</span></button></div> </form> </div> </div> </div> '}}]);