(self.webpackChunk=self.webpackChunk||[]).push([[4227],{3622:function(t){"use strict";t.exports=JSON.parse('{"AllowOnTheFlySubtitleExtraction":"Lejo titrat të ekstraktohen në kohë reale","AllowMediaConversionHelp":"Lejo ose blloko aksesin e veçorisë së transkodimit të medias.","AllowMediaConversion":"Lejo konvertimin e medias","AllowHWTranscodingHelp":"Lejo Tuner-in të transkodojë transmetimet në kohë reale. Kjo mund të ndihmojë në zvogëlimin e transkodimit nga ana e serverit.","AllLibraries":"Të gjithë libraritë","AllLanguages":"Të gjitha gjuhët","AllEpisodes":"Të gjithë episodet","AllComplexFormats":"Të gjithë formatet kompleks (ASS, SSA, VOBSUB, PGS, SUB, IDX, …)","AllChannels":"Të gjithë kanalet","All":"Të gjithë","Alerts":"Alarm","Albums":"Albume","AlbumArtist":"Album Artist","Album":"Album","Aired":"Transmetuar","AirDate":"Data e transmetimit","AdditionalNotificationServices":"Shfleto katalogun e shtojcave për të instaluar të tjera shërbime njoftimi.","AddedOnValue":"Shtuar {0}","AddToPlaylist":"Shto tek lista e luajtjes","AddToPlayQueue":"Shto tek rradha e luajtjes","AddToCollection":"Shto tek koleksioni","Add":"Shto","Actor":"Aktor","AccessRestrictedTryAgainLater":"Aksesi aktualisht është i kufizuar. Ju lutemi provoni përsëri më vonë.","Absolute":"Absolut"}')}}]);