(self.webpackChunk=self.webpackChunk||[]).push([[4544],{29090:function(e,t,n){"use strict";n.r(t),n(63238),n(61418);var s=n(28978),i=n(6594),o=n(27515),r=n(28874),u=(n(51547),n(53913));function a(e,t){for(var n=0;n<t.length;n++){var s=t[n];s.enumerable=s.enumerable||!1,s.configurable=!0,"value"in s&&(s.writable=!0),Object.defineProperty(e,s.key,s)}}var c=function(){function e(t,n){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.view=t,this.params=n,this.apiClient=u.ZP.currentApiClient(),this.sectionsContainer=t.querySelector(".sections"),t.querySelector(".sections").addEventListener("settingschange",h.bind(this))}var t,n;return t=e,(n=[{key:"onResume",value:function(e){if(this.sectionsRendered){var t=this.sectionsContainer;return t?r.ZP.resume(t,e):Promise.resolve()}i.ZP.show();var n=this.view,u=this.apiClient;return this.destroyHomeSections(),this.sectionsRendered=!0,u.getCurrentUser().then((function(t){return r.ZP.loadSections(n.querySelector(".sections"),u,t,s).then((function(){e.autoFocus&&o.Z.autoFocus(n),i.ZP.hide()}))}))}},{key:"onPause",value:function(){var e=this.sectionsContainer;e&&r.ZP.pause(e)}},{key:"destroy",value:function(){this.view=null,this.params=null,this.apiClient=null,this.destroyHomeSections(),this.sectionsContainer=null}},{key:"destroyHomeSections",value:function(){var e=this.sectionsContainer;e&&r.ZP.destroySections(e)}}])&&a(t.prototype,n),e}();function h(){this.sectionsRendered=!1,this.paused||this.onResume({refresh:!0})}t.default=c}}]);