(self.webpackChunk=self.webpackChunk||[]).push([[8399],{41085:function(i){i.exports='<div id="notificationSettingsPage" data-role="page" class="page type-interior notificationConfigurationPage"> <div> <div class="content-primary"> <div class="readOnlyContent"> <div class="notificationList"></div> </div> </div> </div> </div> '}}]);