(self.webpackChunk=self.webpackChunk||[]).push([[3327],{69502:function(t,e,n){"use strict";var i=n(93476),a=n.n(i)()((function(t){return t[1]}));a.push([t.id,".youtubePlayerContainer{background:#000!important;position:fixed!important;top:0;bottom:0;left:0;right:0;display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center}.youtubePlayerContainer.onTop{z-index:1000}.youtubePlayerContainer video{margin:0!important;padding:0!important;width:100%;height:100%}",""]),e.Z=a},77851:function(t,e,n){"use strict";n.r(e);var i=n(1892),a=n.n(i),o=n(69502);a()(o.Z,{insert:"head",singleton:!1}),e.default=o.Z.locals||{}}}]);