(self.webpackChunk=self.webpackChunk||[]).push([[5064],{73238:function(e){e.exports='<div id="addPluginPage" data-role="page" class="page type-interior pluginConfigurationPage" data-backbutton="true"> <div> <div class="content-primary"> <div class="readOnlyContent"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h1 class="sectionTitle pluginName"></h1> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/server/plugins/index.html">${Help}</a> </div> <p id="overview" style="font-style:italic"></p> <p id="description"></p> </div> <div class="verticalSection"> <h2 class="sectionTitle">${HeaderInstall}</h2> <form class="addPluginForm"> <p id="pCurrentVersion"></p> <div id="pSelectVersion" class="hide selectContainer"> <select id="selectVersion" name="selectVersion" is="emby-select" label="${LabelSelectVersionToInstall}"></select> </div> <div id="btnInstallDiv" class="hide"> <button is="emby-button" type="submit" id="btnInstall" class="raised button-submit block"> <span>${Install}</span> </button> <div class="fieldDescription">${ServerRestartNeededAfterPluginInstall}</div> </div> </form> </div> </div> <br/> <div class="readOnlyContent"> <div is="emby-collapse" title="${HeaderDeveloperInfo}"> <div class="collapseContent"> <p id="developer"></p> </div> </div> <div is="emby-collapse" title="${HeaderRevisionHistory}"> <div class="collapseContent"> <div id="revisionHistory"></div> </div> </div> </div> </div> </div> </div> '}}]);