(self.webpackChunk=self.webpackChunk||[]).push([[8098],{31161:function(e,t,n){"use strict";n.r(t),n(63238),n(61418),n(5769);var r=n(53913);function i(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}var s=function(){function e(){!function(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this,e),this.name="Backdrop ScreenSaver",this.type="screensaver",this.id="backdropscreensaver",this.supportsAnonymous=!1}var t,s;return t=e,(s=[{key:"show",value:function(){var e=this,t=r.ZP.currentApiClient();t.getItems(t.getCurrentUserId(),{ImageTypes:"Backdrop",EnableImageTypes:"Backdrop",IncludeItemTypes:"Movie,Series,MusicArtist",SortBy:"Random",Recursive:!0,Fields:"Taglines",ImageTypeLimit:1,StartIndex:0,Limit:200}).then((function(t){t.Items.length&&Promise.all([n.e(5836),n.e(1483)]).then(n.bind(n,1483)).then((function(n){var r=new(0,n.default)({showTitle:!0,cover:!0,items:t.Items});r.show(),e.currentSlideshow=r})).catch(console.error)}))}},{key:"hide",value:function(){return this.currentSlideshow&&(this.currentSlideshow.hide(),this.currentSlideshow=null),Promise.resolve()}}])&&i(t.prototype,s),e}();t.default=s}}]);