(self.webpackChunk=self.webpackChunk||[]).push([[6850],{56850:function(e,i,t){"use strict";function n(e){return window.NativeShell&&window.NativeShell.FileSystem?window.NativeShell.FileSystem.fileExists(e):Promise.reject()}function l(e){return window.NativeShell&&window.NativeShell.FileSystem?window.NativeShell.FileSystem.directoryExists(e):Promise.reject()}t.r(i),t.d(i,{fileExists:function(){return n},directoryExists:function(){return l}}),t(63238),t(61418)}}]);