(self.webpackChunk=self.webpackChunk||[]).push([[7111],{5467:function(e,t,n){"use strict";var o=n(93476),i=n.n(o)()((function(e){return e[1]}));i.push([e.id,".logoScreenSaver{background:#101010;position:fixed;top:0;left:0;right:0;bottom:0;z-index:1000;text-align:center}.logoScreenSaverImage{height:120px;position:absolute;top:50%;margin-top:-60px;margin-left:-197px}",""]),t.Z=i},15535:function(e,t,n){"use strict";n.r(t);var o=n(1892),i=n.n(o),r=n(5467);i()(r.Z,{insert:"head",singleton:!1}),t.default=r.Z.locals||{}}}]);