(self.webpackChunk=self.webpackChunk||[]).push([[7560],{27560:function(l){"use strict";l.exports=JSON.parse('{"AddToCollection":"Aldoni al kolekto","Actor":"Aktoro","Absolute":"Absoluta","ButtonSyncPlay":"SyncPlay","AllLanguages":"Ĉiuj lingvoj","AllEpisodes":"ĉiuj epizodoj","AllComplexFormats":"Ĉiuj Kompleksaj Formatoj (ASS, SSA, VOBSUB, PGS, SUB, IDX, ...)","AllChannels":"Ĉiuj kanaloj","All":"Ĉiuj","Alerts":"Alertoj","Albums":"Albumoj","AlbumArtist":"Albumo-Artisto","Album":"albumo","Aired":"Aerumita","AirDate":"Aera dato","AdditionalNotificationServices":"Foliumu la kromprogramon por instali aldonajn sciigajn servojn.","AddedOnValue":"aldonis {0}","AddToPlaylist":"aldoni al playlist","AddToPlayQueue":"Aldonu ludi voston","Add":"Aldoni","AccessRestrictedTryAgainLater":"Aliro nuntempe estas restriktita. Bonvolu reprovi poste."}')}}]);