(self.webpackChunk=self.webpackChunk||[]).push([[5506],{95506:function(e,t,n){"use strict";n.r(t),n(25901),n(92189),n(63238),n(61418),n(72482);var o=n(47518),i=n(1115),r=n(78695),l=n(74227),a=n(53754),s=n(83094),c=(n(56561),n(78066),n(21865),n(30983),n(16589),n(87132)),u=n.n(c);t.default=(o.Z.tv||o.Z.xboxOne)&&window.confirm?function(e){"string"==typeof e&&(e={label:"",text:e});var t=("<br/>","\n",(e.label||"").split("<br/>").join("\n")),n=prompt(t,e.text||"");return n?Promise.resolve(n):Promise.reject(n)}:function(e){return"string"==typeof e&&(e={title:"",text:e}),function(e){var t={removeOnClose:!0,scrollY:!1};r.Z.tv&&(t.size="fullscreen");var n,o=i.default.createDialog(t);return o.classList.add("formDialog"),o.innerHTML=a.ZP.translateHtml(u(),"core"),r.Z.tv?l.default.centerFocus.on(o.querySelector(".formDialogContent"),!1):(o.querySelector(".dialogContentInner").classList.add("dialogContentInner-mini"),o.classList.add("dialog-fullscreen-lowres")),o.querySelector(".btnCancel").addEventListener("click",(function(){i.default.close(o)})),o.querySelector(".formDialogHeaderTitle").innerHTML=e.title||"",e.description?o.querySelector(".fieldDescription").innerHTML=e.description:o.querySelector(".fieldDescription").classList.add("hide"),function(e,t){var n=e.querySelector("#txtInput");n.label?n.label(t.label||""):n.setAttribute("label",t.label||""),n.value=t.value||""}(o,e),o.querySelector("form").addEventListener("submit",(function(e){return n=o.querySelector("#txtInput").value,e.preventDefault(),e.stopPropagation(),setTimeout((function(){i.default.close(o)}),300),!1})),o.querySelector(".submitText").innerHTML=e.confirmText||a.ZP.translate("ButtonOk"),o.style.minWidth="".concat(Math.min(400,s.ZP.getWindowSize().innerWidth-50),"px"),i.default.open(o).then((function(){return r.Z.tv&&l.default.centerFocus.off(o.querySelector(".formDialogContent"),!1),n||Promise.reject()}))}(e)}},87132:function(e){e.exports='<div class="formDialogHeader"> <button is="paper-icon-button-light" class="btnCancel autoSize" tabindex="-1"> <span class="material-icons arrow_back"></span> </button> <h3 class="formDialogHeaderTitle"></h3> </div> <div class="formDialogContent smoothScrollY"> <div class="dialogContentInner dialog-content-centered" style="padding-top:2em"> <form> <div class="inputContainer"> <input is="emby-input" type="text" id="txtInput" label=""/> <div class="fieldDescription"></div> </div> <div class="formDialogFooter"> <button is="emby-button" type="submit" class="raised btnSubmit block formDialogFooterItem button-submit"> <span class="submitText"></span> </button> </div> </form> </div> </div> '}}]);