(self.webpackChunk=self.webpackChunk||[]).push([[6219],{67366:function(t){t.exports='<div data-role="page" id="forgotPasswordPage" class="page standalonePage forgotPasswordPage"> <div class="padded-left padded-right padded-bottom-page"> <form class="forgotPasswordForm" style="text-align:center;margin:0 auto"> <div style="text-align:left"> <h1>${ButtonForgotPassword}</h1> <div class="inputContainer"> <input is="emby-input" type="text" id="txtName" label="${LabelUser}" autocomplete="off"/> <div class="fieldDescription">${LabelForgotPasswordUsernameHelp}</div> </div> <div> <button is="emby-button" type="submit" class="raised submit block"> <span>${ButtonSubmit}</span> </button> <button is="emby-button" type="button" class="raised cancel block btnCancel" onclick="history.back()"> <span>${ButtonCancel}</span> </button> </div> </div> </form> </div> </div> '}}]);