(self.webpackChunk=self.webpackChunk||[]).push([[9278],{10146:function(e){e.exports='<div id="userParentalControlPage" data-role="page" class="page type-interior"> <div> <div class="content-primary"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle username"></h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/server/users/">${Help}</a> </div> </div> <div data-role="controlgroup" data-type="horizontal" class="localnav" data-mini="true"> <a is="emby-linkbutton" href="#" data-role="button" onclick=\'Dashboard.navigate("useredit.html",!0)\'>${Profile}</a> <a is="emby-linkbutton" href="#" data-role="button" onclick=\'Dashboard.navigate("userlibraryaccess.html",!0)\'>${TabAccess}</a> <a is="emby-linkbutton" href="#" data-role="button" onclick=\'Dashboard.navigate("userparentalcontrol.html",!0)\' class="ui-btn-active">${TabParentalControl}</a> <a is="emby-linkbutton" href="#" data-role="button" onclick=\'Dashboard.navigate("userpassword.html",!0)\'>${HeaderPassword}</a> </div> <form class="userParentalControlForm"> <div class="selectContainer"> <select is="emby-select" id="selectMaxParentalRating" label="${LabelMaxParentalRating}"></select> <div class="fieldDescription">${MaxParentalRatingHelp}</div> </div> <div> <div class="blockUnratedItems"></div> </div> <br/> <div class="verticalSection" style="margin-bottom:2em"> <div class="detailSectionHeader sectionTitleContainer"> <h2 class="sectionTitle">${LabelBlockContentWithTags}</h2> <button is="emby-button" type="button" class="fab btnAddBlockedTag submit" style="margin-left:1em" title="${Add}"> <span class="material-icons add"></span> </button> </div> <div class="blockedTags" style="margin-top:.5em"></div> </div> <div class="accessScheduleSection verticalSection" style="margin-bottom:2em"> <div class="sectionTitleContainer"> <h2 class="sectionTitle">${HeaderAccessSchedule}</h2> <button is="emby-button" type="button" class="fab btnAddSchedule submit" style="margin-left:1em" title="${Add}"> <span class="material-icons add"></span> </button> </div> <p>${HeaderAccessScheduleHelp}</p> <div class="accessScheduleList paperList"></div> </div> <div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </div> </form> </div> </div> </div> '}}]);