(self.webpackChunk=self.webpackChunk||[]).push([[9955],{61495:function(e){e.exports='<div id="dlnaProfilesPage" data-role="page" class="page type-interior dlnaPage withTabs"> <div> <div class="content-primary"> <div class="readOnlyContent"> <div class="verticalSection verticalSection-extrabottompadding"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${HeaderCustomDlnaProfiles}</h2> <a is="emby-linkbutton" href="#!/dlnaprofile.html" class="fab submit" style="margin:0 0 0 1em"> <span class="material-icons add"></span> </a> </div> <p>${CustomDlnaProfilesHelp}</p> <div class="customProfiles"></div> </div> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${HeaderSystemDlnaProfiles}</h2> </div> <p>${SystemDlnaProfilesHelp}</p> <div class="systemProfiles"></div> </div> </div> </div> </div> </div> '}}]);