(self.webpackChunk=self.webpackChunk||[]).push([[9515],{85667:function(e){e.exports='<div id="dashboardGeneralPage" data-role="page" class="page type-interior dashboardHomePage"> <div> <div class="content-primary"> <form class="dashboardGeneralForm"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${Settings}</h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/server/settings.html">${Help}</a> </div> </div> <div class="verticalSection"> <div class="inputContainer"> <input is="emby-input" type="text" id="txtServerName" label="${LabelServerName}"/> <div class="fieldDescription">${LabelServerNameHelp}</div> </div> <div class="selectContainer"> <select is="emby-select" id="selectLocalizationLanguage" label="${LabelPreferredDisplayLanguage}"></select> <div class="fieldDescription"> <div>${LabelDisplayLanguageHelp}</div> <div style="margin-top:.25em"> <a is="emby-linkbutton" rel="noopener noreferrer" class="button-link" href="https://docs.jellyfin.org/general/contributing/index.html" target="_blank">${LearnHowYouCanContribute}</a> </div> </div> </div> </div> <div class="verticalSection verticalSection-extrabottompadding"> <h2>${HeaderPaths}</h2> <div class="inputContainer"> <div style="display:flex;align-items:center"> <div style="flex-grow:1"> <input is="emby-input" id="txtCachePath" label="${LabelCachePath}" autocomplete="off"/> </div> <button type="button" is="paper-icon-button-light" id="btnSelectCachePath" title="${ButtonSelectDirectory}" class="emby-input-iconbutton"><span class="material-icons search"></span></button> </div> <div class="fieldDescription">${LabelCachePathHelp}</div> </div> <div class="inputContainer"> <div style="display:flex;align-items:center"> <div style="flex-grow:1"> <input is="emby-input" id="txtMetadataPath" label="${LabelMetadataPath}" autocomplete="off"/> </div> <button type="button" is="paper-icon-button-light" id="btnSelectMetadataPath" title="${ButtonSelectDirectory}" class="emby-input-iconbutton"><span class="material-icons search"></span></button> </div> <div class="fieldDescription">${LabelMetadataPathHelp}</div> <input type="hidden" id="txtMetadataNetworkPath"/> </div> </div> <div class="verticalSection"> <h2>${HeaderBranding}</h2> <div class="inputContainer"> <input is="emby-input" type="text" id="txtLoginDisclaimer" label="${LabelLoginDisclaimer}"/> <div class="fieldDescription">${LabelLoginDisclaimerHelp}</div> </div> <div class="inputContainer customCssContainer"> <textarea is="emby-textarea" id="txtCustomCss" label="${LabelCustomCss}" class="textarea-mono"></textarea> <div class="fieldDescription">${LabelCustomCssHelp}</div> </div> </div> <br/> <div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </div> </form> </div> </div> </div> '}}]);