(self.webpackChunk=self.webpackChunk||[]).push([[3356],{23206:function(e){e.exports='<div id="dlnaSettingsPage" data-role="page" class="page type-interior withTabs"> <div> <div class="content-primary"> <form class="dlnaSettingsForm"> <div class="verticalSection"> <div class="sectionTitleContainer flex align-items-center"> <h2 class="sectionTitle">${Settings}</h2> <a is="emby-linkbutton" rel="noopener noreferrer" class="raised button-alt headerHelpButton" target="_blank" href="https://docs.jellyfin.org/general/networking/dlna.html">${Help}</a> </div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnablePlayTo"/> <span>${LabelEnableDlnaPlayTo}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelEnableDlnaPlayToHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnableDlnaDebugLogging"/> <span>${LabelEnableDlnaDebugLogging}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelEnableDlnaDebugLoggingHelp}</div> </div> <div class="inputContainer"> <input is="emby-input" type="number" id="txtClientDiscoveryInterval" min="1" max="300" label="${LabelEnableDlnaClientDiscoveryInterval}"/> <div class="fieldDescription">${LabelEnableDlnaClientDiscoveryIntervalHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkEnableServer"/> <span>${LabelEnableDlnaServer}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelEnableDlnaServerHelp}</div> </div> <div class="checkboxContainer checkboxContainer-withDescription"> <label> <input type="checkbox" is="emby-checkbox" id="chkBlastAliveMessages"/> <span>${LabelEnableBlastAliveMessages}</span> </label> <div class="fieldDescription checkboxFieldDescription">${LabelEnableBlastAliveMessagesHelp}</div> </div> <div class="inputContainer"> <input is="emby-input" type="number" id="txtBlastInterval" min="1" max="3600" label="${LabelBlastMessageInterval}"/> <div class="fieldDescription">${LabelBlastMessageIntervalHelp}</div> </div> <div class="selectContainer"> <select is="emby-select" id="selectUser" data-mini="true" label="${LabelDefaultUser}"></select> <div class="fieldDescription">${LabelDefaultUserHelp}</div> </div> <div> <button is="emby-button" type="submit" class="raised button-submit block"> <span>${Save}</span> </button> </div> </form> </div> </div> </div> '}}]);