(self.webpackChunk=self.webpackChunk||[]).push([[3566],{85031:function(e,t,n){"use strict";n.r(t),n.d(t,{default:function(){return o}});var i=n(6594),c=(n(65219),n(78066),n(50447),n(76543));function r(e){return function(e){i.ZP.show();var t=ApiClient,n={};n.EnableRemoteAccess=e.querySelector("#chkRemoteAccess").checked,n.EnableAutomaticPortMapping=e.querySelector("#chkEnableUpnp").checked,t.ajax({type:"POST",data:JSON.stringify(n),url:t.getUrl("Startup/RemoteAccess"),contentType:"application/json"}).then((function(){i.ZP.hide(),c.ZP.navigate("wizardfinish.html")}))}(this),e.preventDefault(),!1}function o(e,t){e.querySelector(".wizardSettingsForm").addEventListener("submit",r),e.addEventListener("viewshow",(function(){document.querySelector(".skinHeader").classList.add("noHomeButtonHeader")})),e.addEventListener("viewhide",(function(){document.querySelector(".skinHeader").classList.remove("noHomeButtonHeader")}))}}}]);