(self.webpackChunk=self.webpackChunk||[]).push([[4650],{72989:function(t,e,i){"use strict";var o=i(93476),n=i.n(o)()((function(t){return t[1]}));n.push([t.id,".videoPlayerContainer{position:fixed!important;top:0;bottom:0;left:0;right:0;display:-webkit-flex;display:flex;-webkit-align-items:center;align-items:center;background:#000!important}.videoPlayerContainer-onTop{z-index:1000}.videoPlayerContainer .libassjs-canvas-parent{-webkit-order:-1;order:-1}video[controls]::-webkit-media-controls{display:none!important}.htmlvideoplayer{margin:0!important;padding:0!important;width:100%;height:100%}.htmlvideoplayer::cue{background-color:transparent;text-shadow:.14em .14em .14em #000;-webkit-font-smoothing:antialiased;font-family:inherit;line-height:normal}.htmlvideoplayer::-webkit-media-text-track-container{font-size:170%!important;line-height:50%}.htmlvideoplayer::-webkit-media-text-track-display{max-width:70%;margin-left:15%}.videoSubtitles{position:fixed;bottom:0;text-align:center;left:0;right:0;color:#fff;font-size:170%}.videoSubtitlesInner{max-width:70%;background-color:rgba(0,0,0,.8);margin:auto;display:inline-block}@-webkit-keyframes htmlvideoplayer-zoomin{0%{-webkit-transform:scale3d(.2,.2,.2);transform:scale3d(.2,.2,.2);opacity:.6}to{-webkit-transform:none;transform:none;opacity:1}}@keyframes htmlvideoplayer-zoomin{0%{-webkit-transform:scale3d(.2,.2,.2);transform:scale3d(.2,.2,.2);opacity:.6}to{-webkit-transform:none;transform:none;opacity:1}}",""]),e.Z=n},71756:function(t,e,i){"use strict";i.r(e);var o=i(1892),n=i.n(o),a=i(72989);n()(a.Z,{insert:"head",singleton:!1}),e.default=a.Z.locals||{}}}]);