.skinHeader,
html {
    color: #222;
    color: rgba(0, 0, 0, 0.87);
}

.wizardStartForm,
.ui-corner-all,
.ui-shadow {
    background-color: #303030;
}

.emby-collapsible-button {
    border-color: #ccc;
    border-color: rgba(0, 0, 0, 0.158);
}

.collapseContent {
    background-color: #eaeaea;
}

.formDialogHeader:not(.formDialogHeader-clear),
.skinHeader-withBackground {
    color: rgba(0, 0, 0, 0.7);
    background: #303030;
    background: linear-gradient(to right, #bcbcbc, #a7b4b7, #beb5a5, #adbec2, #b9c7cb);
}

.skinHeader.semiTransparent {
    backdrop-filter: none !important;
}

.layout-tv .skinHeader.semiTransparent {
    background: none;
}

.pageTitleWithDefaultLogo {
    background-image: url(../../assets/img/banner-dark.png);
}

.layout-tv .pageTitleWithDefaultLogo {
    background-image: url(../../assets/img/icon-transparent.png);
}

html {
    background: #d5e9f2;
}

.backgroundContainer,
.dialog,
.nowPlayingPlaylist,
.nowPlayingContextMenu {
    background: #d5e9f2;
    -webkit-background-size: 100% 100%;
    background-size: 100% 100%;
}

.backgroundContainer.withBackdrop {
    background: -webkit-gradient(linear, left top, left bottom, from(rgba(192, 212, 222, 0.94)), color-stop(rgba(235, 250, 254, 0.94)), color-stop(rgba(227, 220, 212, 0.94)), color-stop(rgba(206, 214, 216, 0.94)), to(rgba(192, 211, 218, 0.94)));
    background: -webkit-linear-gradient(top, rgba(192, 212, 222, 0.94), rgba(235, 250, 254, 0.94), rgba(227, 220, 212, 0.94), rgba(206, 214, 216, 0.94), rgba(192, 211, 218, 0.94));
    background: -o-linear-gradient(top, rgba(192, 212, 222, 0.94), rgba(235, 250, 254, 0.94), rgba(227, 220, 212, 0.94), rgba(206, 214, 216, 0.94), rgba(192, 211, 218, 0.94));
    background: linear-gradient(to bottom, rgba(192, 212, 222, 0.94), rgba(235, 250, 254, 0.94), rgba(227, 220, 212, 0.94), rgba(206, 214, 216, 0.94), rgba(192, 211, 218, 0.94));
}

.actionSheet {
    background: #f0f0f0;
}

@media (hover: hover) and (pointer: fine) {
    .paper-icon-button-light:hover:not(:disabled) {
        color: #00a4dc;
        background-color: rgba(0, 164, 220, 0.2);
    }
}

.paper-icon-button-light:active:not(:disabled) {
    color: #00a4dc;
    background-color: rgba(0, 164, 220, 0.2);
}

.paper-icon-button-light.show-focus:focus {
    color: #00a4dc;
}

.fab,
.raised {
    background: #fff;
    background: rgba(0, 0, 0, 0.14);
    color: inherit;
}

.fab:focus,
.raised:focus {
    background: rgba(0, 0, 0, 0.24);
}

.button-submit {
    background: #00a4dc;
    color: #fff;
}

.button-submit:focus {
    background: #0cb0e8;
}

.button-delete {
    background: rgb(247, 0, 0);
    color: rgba(255, 255, 255, 0.87);
}

.checkboxLabel {
    color: inherit;
}

.checkboxListLabel,
.inputLabel,
.inputLabelUnfocused,
.paperListLabel,
.textareaLabelUnfocused {
    color: #555;
    color: rgba(0, 0, 0, 0.7);
}

.button-link,
.inputLabelFocused,
.selectLabelFocused,
.textareaLabelFocused {
    color: #00a4dc;
}

.checkboxOutline {
    border-color: currentColor;
}

.paperList,
.visualCardBox,
.cardBox:not(.visualCardBox) .cardPadder {
    background-color: rgba(0, 0, 0, 0.1);
    border-radius: 0.5rem;
}

.defaultCardBackground1 {
    background-color: #009688;
}

.defaultCardBackground2 {
    background-color: #d32f2f;
}

.defaultCardBackground3 {
    background-color: #0288d1;
}

.defaultCardBackground4 {
    background-color: #388e3c;
}

.defaultCardBackground5 {
    background-color: #f57f17;
}

.formDialogFooter:not(.formDialogFooter-clear) {
    border-top: 1px solid #ddd;
    border-top: 1px solid rgba(0, 0, 0, 0.08);
}

.cardText-secondary,
.fieldDescription,
.guide-programNameCaret,
.listItem .secondary,
.nowPlayingBarSecondaryText,
.programSecondaryTitle,
.secondaryText {
    color: #888;
    color: rgba(0, 0, 0, 0.5);
}

.actionsheetDivider {
    background: #ddd;
    background: rgba(0, 0, 0, 0.14);
}

.cardFooter-vibrant .cardText-secondary {
    color: inherit;
    opacity: 0.5;
}

.cardImageContainer {
    border-radius: 0.5rem;
}

.formDialogHeader a,
.toast {
    color: #fff;
}

.actionSheetMenuItem:hover {
    background-color: #ddd;
}

.toast {
    background: #303030;
    color: rgba(255, 255, 255, 0.87);
}

.appfooter,
.formDialogFooter:not(.formDialogFooter-clear),
.playlistSectionButton {
    color: rgba(0, 0, 0, 0.7);
    background: #303030;
    background: -webkit-gradient(linear, left top, right top, from(#bcbcbc), color-stop(#a7b4b7), color-stop(#beb5a5), color-stop(#adbec2), to(#b9c7cb));
    background: -webkit-linear-gradient(left, #bcbcbc, #a7b4b7, #beb5a5, #adbec2, #b9c7cb);
    background: -o-linear-gradient(left, #bcbcbc, #a7b4b7, #beb5a5, #adbec2, #b9c7cb);
    background: linear-gradient(to right, #bcbcbc, #a7b4b7, #beb5a5, #adbec2, #b9c7cb);
}

.nowPlayingBarSecondaryText {
    color: #999;
}

.itemSelectionPanel {
    border: 1px solid #00a4dc;
}

.selectionCommandsPanel {
    background: #00a4dc;
    color: #fff;
}

.upNextDialog-countdownText {
    color: #00a4dc;
}

.alphaPickerButton {
    color: #555;
    color: rgba(0, 0, 0, 0.7);
    background-color: transparent;
}

.alphaPickerButton-selected,
.alphaPickerButton-tv:focus {
    background-color: #00a4dc;
    color: #fff !important;
}

.detailRibbon {
    background: #303030;
    background: linear-gradient(to right, #bcbcbc, #a7b4b7, #beb5a5, #adbec2, #b9c7cb);
}

.layout-tv .detailRibbon {
    background: none;
}

.detailTableBodyRow-shaded:nth-child(even) {
    background: #f8f8f8;
    background: rgba(0, 0, 0, 0.1);
}

.listItem-border {
    border-color: rgba(0, 0, 0, 0.1) !important;
}

.listItem:focus {
    background: rgba(0, 0, 0, 0.2);
}

.progressring-spiner {
    border-color: #00a4dc;
}

.mediaInfoText {
    color: #333;
    background: #fff;
}

.emby-input,
.emby-textarea {
    color: inherit;
    background: rgba(255, 255, 255, 0.9);
    border: 0.16em solid rgba(0, 0, 0, 0.158);
    -webkit-border-radius: 0.2em;
    border-radius: 0.2em;
}

.emby-input:focus,
.emby-textarea:focus {
    border-color: #00a4dc;
}

.emby-select-withcolor {
    color: inherit;
    background: rgba(255, 255, 255, 0.9);
    border: 0.07em solid rgba(0, 0, 0, 0.158);
}

.emby-checkbox:checked + span + .checkboxOutline,
.emby-select-withcolor:focus {
    border-color: #00a4dc;
}

.emby-checkbox:focus + span + .checkboxOutline {
    border-color: #fff;
}

.emby-checkbox:checked + span + .checkboxOutline {
    background-color: #00a4dc;
}

.itemProgressBarForeground {
    background: linear-gradient(90deg, rgba(0, 210, 201, 1) 0%, rgba(13, 194, 98, 1) 28%, rgba(0, 75, 185, 1) 100%);
}

.itemProgressBar {
    background: rgba(230, 230, 230, 0.8);
    height: 0.18rem;
}

.innerCardFooter {
    border-radius: 0.14rem;
    margin: 0.4rem 0.5rem 0.4rem 0.5rem;
}

.emby-checkbox:focus:not(:checked) + span + .checkboxOutline {
    border-color: #00a4dc;
}

.emby-select-withcolor > option {
    color: #000;
    background: #fff;
}

.emby-select-tv-withcolor:focus {
    background-color: #00a4dc;
    color: #fff;
}

.itemProgressBarForeground-recording {
    background-color: #cb272a;
}

.countIndicator,
.fullSyncIndicator,
.playedIndicator {
    background: #00a4dc;
}

.fullSyncIndicator {
    color: #fff;
}

.mainDrawer {
    background: #fff;
}

.navMenuOption:hover {
    background: #f2f2f2;
}

.navMenuOption-selected {
    background: #00a4dc !important;
    color: #fff;
}

.emby-button.show-focus:focus {
    background: #00a4dc;
    color: #fff;
}

.emby-tab-button {
    color: #999;
}

.emby-tab-button-active {
    color: #fff;
}

.emby-tab-button.show-focus:focus {
    color: #fff;
}

.emby-tab-button:hover {
    color: #fff;
}

.channelPrograms,
.guide-channelHeaderCell,
.programCell {
    border-color: #555;
    border-color: rgba(0, 0, 0, 0.1);
}

.programCell-sports {
    background: #3949ab !important;
}

.programCell-movie {
    background: #5e35b1 !important;
}

.programCell-kids {
    background: #039be5 !important;
}

.programCell-news {
    background: #43a047 !important;
}

.programCell-active {
    background: rgba(0, 0, 0, 0.1) !important;
}

.guide-channelHeaderCell:focus,
.programCell:focus {
    background-color: #00a4dc !important;
    color: #fff !important;
}

.guide-programTextIcon {
    color: #1e1e1e;
    background: #555;
}

.guide-headerTimeslots {
    color: inherit;
}

.guide-date-tab-button {
    color: #555;
    color: rgba(0, 0, 0, 0.54);
}

.guide-date-tab-button.emby-tab-button-active,
.guide-date-tab-button:focus {
    color: #00a4dc;
}

.guide-date-tab-button.show-focus:focus {
    background-color: #00a4dc;
    color: #fff;
}

.infoBanner {
    color: #000;
    background: #fff3a5;
    padding: 1em;
    -webkit-border-radius: 0.25em;
    border-radius: 0.25em;
}

.ratingbutton-icon-withrating {
    color: #c33;
}

.downloadbutton-icon-complete,
.downloadbutton-icon-on {
    color: #4285f4;
}

.playstatebutton-icon-played {
    color: #c33;
}

.buttonActive {
    color: #00a4dc !important;
}

.card:focus .cardBox.visualCardBox,
.card:focus .cardBox:not(.visualCardBox) .cardScalable {
    border-radius: 0.5rem;
    border-color: #00a4dc !important;
}

.card.show-focus:not(.show-animation) .cardBox.visualCardBox,
.card.show-focus:not(.show-animation) .cardBox:not(.visualCardBox) .cardScalable {
    border-radius: 1rem;
}

.blurhash-canvas {
    border-radius: 0.5rem;
}

.itemDetailImage,
.cardOverlayContainer {
    border-radius: 0.5rem;
}

.metadataSidebarIcon {
    color: #00a4dc;
}
