(self.webpackChunk=self.webpackChunk||[]).push([[6390],{91824:function(e){e.exports='<div id="scheduledTasksPage" data-role="page" class="page type-interior scheduledTasksConfigurationPage"> <style>.taskProgressOuter{height:6px;background:#eee;border-radius:2px}.taskProgressInner{border-radius:2px;height:100%;background:#00a4dc}</style> <div> <div class="content-primary"> <div class="divScheduledTasks readOnlyContent"></div> </div> </div> </div> '}}]);